import unittest
from emoatlas import EmoScores


class EmoAtlasTestCase(unittest.TestCase):
    def test_zscores(self):
        emos = EmoScores()
        sample_text = """In this text, we prefer dogs becase they are happy and dogs are positive.
        Good dogs make good friends. Cats however are bad and have negative links. We dislike cats."""
        fmnt = emos.formamentis_network(sample_text)
        bag_of_words_dog = " ".join(
            [pair[1] for pair in fmnt.edges if pair[0].lower() == "dog"]
        )
        zscores = emos.zscores(bag_of_words_dog)
        self.assertListEqual(
            list(zscores.keys()),
            [
                "anger",
                "trust",
                "surprise",
                "disgust",
                "joy",
                "sadness",
                "fear",
                "anticipation",
            ],
        )


if __name__ == "__main__":
    unittest.main()



_positive = set(
    [
        "abba",
        "vermogen",
        "NO TRANSLATION",
        "absoluut",
        "absolutie",
        "geabsorbeerd",
        "overvloedig",
        "academische",
        "academie",
        "aanvaardbaar",
        "aanvaarding",
        "beschikbaar",
        "accolade",
        "accommodatie",
        "begeleiding",
        "bereiken",
        "volbracht",
        "prestatie",
        "overeenstemming",
        "verantwoording",
        "verantwoordelijk",
        "geaccrediteerd",
        "NO TRANSLATION",
        "accuraat",
        "aas",
        "bereiken",
        "prestatie",
        "erkenning",
        "verkrijgen",
        "verwerven",
        "acrobaat",
        "actie",
        "werkelijk",
        "scherpheid",
        "scherpzinnigheid",
        "zich aanpassen",
        "aanpasbaar",
        "adressen",
        "bedreven",
        "NO TRANSLATION",
        "toevoegsel",
        "bewonderenswaardig",
        "admiraal",
        "bewondering",
        "bewonderen",
        "bewonderaar",
        "toelaatbaar",
        "aanbiddelijk",
        "aanbidding",
        "dol zijn op",
        "van te voren",
        "gevorderd",
        "vordering",
        "voordeel",
        "voordelig",
        "komst",
        "avontuur",
        "avontuurlijk",
        "raadzaam",
        "adviseren",
        "raadgever",
        "voorspraak",
        "aesthetisch",
        "schoonheidsleer",
        "minzaam",
        "genegenheid",
        "aangesloten",
        "bevestigen",
        "bevestiging",
        "bevestigend",
        "bevestigend",
        "rijkdom",
        "zijrivier",
        "veroorloven",
        "NO TRANSLATION",
        "behendig",
        "behendigheid",
        "mee eens",
        "aangenaam",
        "Akkoord",
        "akkoord",
        "overeenkomst",
        "landbouw",
        "verder",
        "steun",
        "helpen",
        "albast",
        "waakzaamheid",
        "NO TRANSLATION",
        "levend",
        "verminderen",
        "trouw",
        "allegro",
        "verlichten",
        "verlichting",
        "geallieerd",
        "toelaatbaar",
        "verleiden",
        "verleidelijk",
        "bondgenoot",
        "almachtig",
        "aloha",
        "verbazend",
        "ambassadeur",
        "ambitie",
        "verbeteren",
        "amen",
        "vatbaar",
        "wijzigen",
        "compensatie",
        "faciliteiten",
        "beminnelijk",
        "minnelijk",
        "amnestie",
        "NO TRANSLATION",
        "amuseren",
        "geamuseerd",
        "amusement",
        "amusant",
        "analyst",
        "anker",
        "ankerplaats",
        "engel",
        "engelachtig",
        "bezielen",
        "geanimeerde",
        "antibiotica",
        "tegengif",
        "antifungale",
        "antiek",
        "antiseptisch",
        "aplomb",
        "verontschuldigend",
        "verontschuldigen",
        "verontschuldiging",
        "apostel",
        "applaus",
        "waardering",
        "goedkeuring",
        "goedkeuring",
        "goedkeuren",
        "goedkeuren",
        "geneigd",
        "aanleg",
        "oudheidkunde",
        "vurig",
        "ijver",
        "aristocratie",
        "aristocratisch",
        "schild",
        "aroma",
        "wekken",
        "rangschikking",
        "kunst",
        "articuleren",
        "articulatie",
        "ambachtsman",
        "NO TRANSLATION",
        "artistiek",
        "overwicht",
        "beklimming",
        "aspiratie",
        "streven",
        "eerzuchtig",
        "bijeenkomst",
        "instemming",
        "beweren",
        "middelen",
        "helpen",
        "bijstand",
        "associëren",
        "lenigen",
        "zekerheid",
        "verzekerd",
        "NO TRANSLATION",
        "verbazing",
        "astroloog",
        "astronaut",
        "astronoom",
        "geslepen",
        "atleet",
        "atletisch",
        "atoom",
        "verzoenen",
        "verzoening",
        "gehechtheid",
        "bereikbaar",
        "bereiking",
        "begeleider",
        "aandacht",
        "attent",
        "getuigen",
        "advocaat",
        "aantrekkelijkheid",
        "aantrekkelijkheid",
        "vergroten",
        "augustus",
        "tante",
        "aura",
        "gunstig",
        "authentiek",
        "echtheid",
        "auteur",
        "gezaghebbend",
        "autoriteit",
        "machtiging",
        "gemachtigde",
        "avatar",
        "onderscheiding",
        "ja",
        "aye",
        "baby",
        "baccalaureaat",
        "ruggegraat",
        "balans",
        "evenwichtige",
        "ballade",
        "ballet",
        "stemming",
        "balsem",
        "banket",
        "doop",
        "doop",
        "bard",
        "koopje",
        "basketbal",
        "bastion",
        "bad",
        "balk",
        "stralend",
        "verfraaiing",
        "mooi",
        "mooi maken",
        "schoonheid",
        "grondslag",
        "bier",
        "passend",
        "betonen",
        "geloven",
        "weldoener",
        "gunstig",
        "voordeel",
        "welwillendheid",
        "goedaardig",
        "ligplaats",
        "verloofd",
        "verbetering",
        "drank",
        "bijbels",
        "tweetalig",
        "geboorte",
        "verjaardag",
        "onberispelijk",
        "zegenen",
        "gezegend",
        "zegen",
        "zegeningen",
        "geluk",
        "zalig",
        "bloedeloos",
        "bloeien",
        "bloesem",
        "lijfwacht",
        "stoutmoedig",
        "vrijmoedigheid",
        "ondersteunen",
        "welvaart",
        "NO TRANSLATION",
        "bonus",
        "boekachtig",
        "boekenwinkel",
        "zegen",
        "rijkelijk",
        "gave",
        "boeket",
        "hersenen",
        "moed",
        "ontbijt",
        "bruids",
        "bruid",
        "bruidegom",
        "bruidsmeisje",
        "opvrolijken",
        "helderheid",
        "briljant",
        "brokaat",
        "broer",
        "broederschap",
        "broederlijk",
        "makker",
        "bouwen",
        "gebouw",
        "bulldog",
        "kogelvrij",
        "boei",
        "Buss",
        "butler",
        "boterachtig",
        "mollig",
        "gezoem",
        "taxi",
        "kabinet",
        "cafe",
        "rekenmachine",
        "kalf",
        "kalmte",
        "kanarie",
        "openhartig",
        "kandidaat",
        "geglaceerd",
        "kapitalist",
        "gezagvoerder",
        "boeien",
        "boeiende",
        "carrière",
        "voorzichtig",
        "voorzichtig",
        "strelen",
        "huisbewaarder",
        "Carol",
        "cascade",
        "contant geld",
        "categorisch",
        "tegemoet te komen",
        "purgeermiddel",
        "kathedraal",
        "voorzichtig",
        "behoedzaam",
        "beroemd",
        "vieren",
        "viering",
        "hemel-",
        "centrum",
        "centurion",
        "hersen-",
        "ceremonie",
        "zekerheid",
        "Voorzitter",
        "voorzitter",
        "kampioen",
        "zingen",
        "lader",
        "liefdadig",
        "goed doel",
        "betoveren",
        "charmant",
        "kuisheid",
        "chattering",
        "checklist",
        "juichen",
        "vrolijk",
        "opgewektheid",
        "cheering",
        "NO TRANSLATION",
        "scheikundige",
        "koesteren",
        "kers-",
        "opperhoofd",
        "kind",
        "kinderjaren",
        "piepen",
        "beitel",
        "ridderlijkheid",
        "chocola",
        "keuze",
        "koor",
        "koor-",
        "koor",
        "uitgekozen",
        "chowder",
        "kroniek",
        "gniffel",
        "kerk",
        "cider",
        "besnijdenis",
        "inwoner",
        "civiel",
        "beleefdheid",
        "beschaving",
        "beschaafd",
        "helderziende",
        "klap",
        "nader toelichten",
        "klassiek",
        "klassiek",
        "classics",
        "classificeren",
        "schoon",
        "schoonmaak",
        "zindelijkheid",
        "schoon",
        "reinigen",
        "reiniging",
        "opruiming",
        "helderheid",
        "klerikaal",
        "knap",
        "handigheid",
        "climax",
        "geslotenheid",
        "sluiting",
        "NO TRANSLATION",
        "clown",
        "coalitie",
        "kust",
        "naast elkaar bestaan",
        "overtuigend",
        "cognitieve",
        "samenhang",
        "samenhangend",
        "samenhangend",
        "collectief",
        "kolonel",
        "kolossaal",
        "comfort",
        "commandant",
        "bevelvoerend",
        "herdenken",
        "herdenking",
        "herdenkings-",
        "aanprijzen",
        "prijzenswaardig",
        "commentator",
        "toegewijd",
        "commodore",
        "Gemenebest",
        "communiceren",
        "communicatief vaardig",
        "gemeenschap",
        "gemeenschap",
        "commutatie",
        "omzetten",
        "metgezel",
        "mededogen",
        "medelijdend",
        "verenigbaarheid",
        "verenigbaar",
        "dwingende",
        "compenseren",
        "compenserende",
        "bevoegdheid",
        "competentie",
        "competent",
        "inschikkelijkheid",
        "aanvulling",
        "complementair",
        "helemaal",
        "volledigheid",
        "het invullen van",
        "voltooiing",
        "nakoming",
        "compliant",
        "NO TRANSLATION",
        "samengesteld",
        "componist",
        "kalmte",
        "begrijpen",
        "uitgebreid",
        "kameraad",
        "concentrisch",
        "verzoening",
        "afsluitende",
        "verdrag",
        "concordantie",
        "rouwbeklag",
        "vergoelijken",
        "bevorderlijk",
        "geleidingsvermogen",
        "verbonden",
        "vertrouwen",
        "zelfverzekerd",
        "bevestigd",
        "conformiteit",
        "sympathiek",
        "felicitatie-",
        "gemeente",
        "congruentie",
        "fijnproever",
        "geweten",
        "gewetensvol",
        "bewustzijn",
        "wijding",
        "gesprek",
        "conserveren",
        "aanzienlijk",
        "attent",
        "consistentie",
        "troosten",
        "medeklinker",
        "standvastigheid",
        "constante",
        "grondwettelijk",
        "construeren",
        "doortrapt",
        "contact",
        "overpeinzing",
        "inhoud",
        "doorgaan met",
        "contour",
        "bijdragen",
        "bijdrager",
        "gemak",
        "geschikt",
        "klooster",
        "conventie",
        "vertrouwd",
        "spraakzaam",
        "converteren",
        "overtuigen",
        "koel",
        "koelte",
        "samenwerken",
        "meewerkende",
        "samenwerking",
        "coöperatieve",
        "kern",
        "kroning",
        "corporatie",
        "stoffelijk",
        "correctief",
        "correspondentie",
        "bevestigen",
        "kosmopolitisch",
        "knus",
        "raad",
        "raad",
        "raadgever",
        "tellen",
        "gravin",
        "moed",
        "moedig",
        "beleefd",
        "hoffelijkheid",
        "verkering",
        "inham",
        "verbond",
        "wieg",
        "ambacht",
        "ambachtsman",
        "room",
        "creëren",
        "creatief",
        "geloof",
        "geloofsbrief",
        "geloofwaardigheid",
        "geloofwaardig",
        "credit",
        "NO TRANSLATION",
        "gecrediteerd",
        "crescendo",
        "critiek",
        "bekroning",
        "beslissend",
        "kristal",
        "knuffelen",
        "culinaire",
        "hoogtepunt",
        "verbouwen",
        "bewerkt",
        "teelt",
        "cultuur",
        "uithardbare",
        "nieuwsgierigheid",
        "Krul",
        "kussen",
        "klant",
        "schattig",
        "cutters",
        "lady",
        "dans",
        "gedurfd",
        "schat",
        "zwierig",
        "dochter",
        "dageraad",
        "transactie",
        "Geachte",
        "debat",
        "fatsoen",
        "fatsoenlijk",
        "verklarend",
        "toewijding",
        "verdedigen",
        "verdedigde",
        "verdediger",
        "verdedigen",
        "verdediging",
        "eerbied",
        "definitief",
        "mate",
        "verrukkelijk",
        "delegeren",
        "beraadslagen",
        "heerlijk",
        "genot",
        "verrukt",
        "verrukkelijk",
        "verlossing",
        "levering",
        "democratie",
        "bewijsbaar",
        "aanwijzend",
        "diepte",
        "beschrijvend",
        "verdienen",
        "verdienden",
        "ontwerper",
        "wenselijk",
        "verlangen",
        "verlangend",
        "bestemming",
        "opsporen",
        "opsporing",
        "bepaling",
        "vastbesloten",
        "ontwikkelen",
        "stichtelijk",
        "vroom",
        "behendigheid",
        "diamant",
        "dagboek",
        "woordenboek",
        "didactisch",
        "dieet-",
        "waardig",
        "waardigheid",
        "ijver",
        "avondeten",
        "diplomatie",
        "diplomatisch",
        "regisseur",
        "ontdekking",
        "NO TRANSLATION",
        "goeddunken",
        "discretionaire",
        "discussie",
        "ontsmetting",
        "geneigd",
        "verspreiden",
        "distillatie",
        "onderscheid",
        "liedje",
        "afwisselend",
        "afleidingsmanoeuvre",
        "goddelijkheid",
        "doctor",
        "dader",
        "vasthoudend",
        "dolfijn",
        "don",
        "schenking",
        "ongetwijfeld",
        "duif",
        "donsachtig",
        "duet",
        "hertog",
        "duurzaamheid",
        "duurzaam",
        "plichtmatig",
        "gretig",
        "gretigheid",
        "graaf",
        "verdienen",
        "ernstig",
        "ernstig",
        "ernst",
        "gemak",
        "servituut",
        "NO TRANSLATION",
        "eten",
        "extase",
        "extatisch",
        "stichting",
        "onderwijzen",
        "geleerd",
        "leerzaam",
        "effectief",
        "werkzaamheid",
        "rendement",
        "doeltreffend",
        "inspanning",
        "ejaculatie",
        "uitwerking",
        "opgetogen",
        "ouderling",
        "oudste",
        "kiezen",
        "elektrisch",
        "elektriciteit",
        "elegantie",
        "elegant",
        "verhoging",
        "in aanmerking komende",
        "de elite",
        "welsprekendheid",
        "welsprekend",
        "ophelderen",
        "emancipatie",
        "omhelzing",
        "emeritus",
        "eminentie",
        "eminent",
        "uitmuntend",
        "NO TRANSLATION",
        "empathie",
        "machtigen",
        "wedijveren",
        "in staat stellen",
        "enablement",
        "betoveren",
        "betoverde",
        "betoverend",
        "NO TRANSLATION",
        "aanmoedigen",
        "aanmoediging",
        "encyclopedie",
        "streven",
        "begiftigen",
        "voorzien",
        "schenking",
        "uithoudingsvermogen",
        "verduren",
        "energiek",
        "bezet",
        "innemend",
        "verbeteren",
        "genieten",
        "genieten van",
        "verlichten",
        "verlichting",
        "verlevendigen",
        "verrijken",
        "ensemble",
        "vlag",
        "ondernemend",
        "vermaken",
        "vermaakt",
        "onderhoudend",
        "vermaak",
        "enthousiasme",
        "enthousiast",
        "NO TRANSLATION",
        "ephemeris",
        "episch",
        "samenvatting",
        "gelijkheid",
        "even",
        "evenwicht",
        "eigen vermogen",
        "boodschap",
        "erudiet",
        "geest",
        "essentieel",
        "gevestigd",
        "achting",
        "esthetische",
        "ethisch",
        "ethiek",
        "evergreen",
        "eeuwigdurend",
        "evident",
        "evolutie",
        "verheffen",
        "verheerlijking",
        "verheven",
        "overtreffen",
        "uitmunten",
        "uitmuntendheid",
        "uitstekend",
        "uitwisseling",
        "prikkelbaar",
        "opwinding",
        "prikkelen",
        "opgewonden",
        "opwinding",
        "opwindend",
        "voorbeeldig",
        "vrijstelling",
        "opvrolijking",
        "vermanen",
        "vermaning",
        "bestaan",
        "exotisch",
        "verwachten",
        "verwachting",
        "doelmatig",
        "expeditie",
        "ervaren",
        "deskundige",
        "expertise",
        "leg uit",
        "voortreffelijk",
        "fijn",
        "uitbreiden",
        "uitgebreid",
        "extra",
        "buitengewoon",
        "losmaken",
        "uitbundigheid",
        "vergemakkelijken",
        "feiten",
        "faculteit",
        "NO TRANSLATION",
        "eerlijk",
        "tamelijk",
        "geloof",
        "getrouw",
        "roem",
        "vertrouwd",
        "vertrouwdheid",
        "beroemd",
        "beroemd",
        "zin in hebben",
        "fanfare",
        "fascinerend",
        "betovering",
        "in de mode",
        "onberispelijk",
        "gunstig",
        "favoriete",
        "favoritisme",
        "onbevreesd",
        "prestatie",
        "voorzien zijn van",
        "geluk",
        "kameraad",
        "gemeenschap",
        "vrouw",
        "vruchtbaar",
        "ijver",
        "festival",
        "feestelijk",
        "NO TRANSLATION",
        "trouw",
        "feest",
        "Tenslotte",
        "opschik",
        "finesse",
        "vuurbol",
        "vuurvast",
        "stevigheid",
        "NO TRANSLATION",
        "fitting",
        "spaninrichting",
        "vleiend",
        "vloot",
        "flexibiliteit",
        "bloemen",
        "stroom",
        "bloemrijk",
        "doorspoelen",
        "vliegend",
        "focus",
        "genegenheid",
        "eten",
        "voetbal",
        "verdraagzaamheid",
        "voor-",
        "voorouders",
        "voorgaande",
        "voorman",
        "voorloper",
        "voorzien",
        "voorziene",
        "vooruitziendheid",
        "smederij",
        "vergeven",
        "vergeven",
        "vergevensgezind",
        "formatieve",
        "formule",
        "NO TRANSLATION",
        "aanstaande",
        "versterken",
        "standvastigheid",
        "vesting",
        "gelukkig",
        "fortuin",
        "vooruit",
        "gevonden",
        "fundament",
        "geurig",
        "openhartig",
        "openhartigheid",
        "broederlijk",
        "vrijheid",
        "vrij",
        "vriend",
        "vriendelijkheid",
        "vriendelijk",
        "vriendschap",
        "dartel",
        "dartelen",
        "zuinig",
        "vruchtbaar",
        "vervullen",
        "vervulling",
        "vol",
        "geheel",
        "pret",
        "fundamenteel",
        "zekering",
        "fusie",
        "krijgen",
        "wint",
        "galante",
        "galanterie",
        "in overvloed",
        "tuin-",
        "granaat",
        "garnizoen",
        "krant",
        "versnelling",
        "edelsteen",
        "algemeen",
        "vrijgevigheid",
        "genereus",
        "geniaal",
        "genie",
        "deftig",
        "heer",
        "vriendelijkheid",
        "Gentry",
        "oprecht",
        "geranium",
        "gift",
        "begaafd",
        "gigantisch",
        "giechelen",
        "balk",
        "geven",
        "blij",
        "blijdschap",
        "vrolijkheid",
        "glijden",
        "schijnsel",
        "schitterend",
        "verheerlijking",
        "verheerlijken",
        "heerlijkheid",
        "glans",
        "gloed",
        "gloeiend",
        "god",
        "godvruchtig",
        "buitenkansje",
        "goud",
        "goed",
        "flink",
        "goedheid",
        "goederen",
        "welwillendheid",
        "prachtig",
        "Evangelie",
        "regeren",
        "genade",
        "bevallig",
        "genadig",
        "genadig",
        "diploma uitreiking",
        "kleinkinderen",
        "grootsheid",
        "grootmoeder",
        "verlenen",
        "toegekend",
        "dankbaar",
        "bevredigen",
        "dankbaarheid",
        "groter",
        "grootheid",
        "groen",
        "groet",
        "gezellig",
        "grijns",
        "maalkoren",
        "gruis",
        "grondslag",
        "groeien",
        "groei",
        "garantie",
        "bewaker",
        "voogd",
        "voogdij",
        "gubernatorial",
        "de begeleiding",
        "gids",
        "gids",
        "goeroe",
        "ingewanden",
        "gymnast",
        "leefgebied",
        "flink",
        "handig",
        "gelukkig",
        "geluk",
        "gelukkig",
        "hardy",
        "harmonieus",
        "harmonie",
        "oogst",
        "veilige haven",
        "vooruitgang",
        "genezen",
        "genezing",
        "gezond",
        "gezond",
        "oprecht",
        "haard",
        "hartelijk",
        "hemels",
        "hemelen",
        "gewicht",
        "helm",
        "helper",
        "nuttig",
        "kruiden",
        "held",
        "heldhaftig",
        "heroics",
        "heldin",
        "heldenmoed",
        "bloeitijd",
        "hilarisch",
        "hilariteit",
        "huren",
        "hobby",
        "vakantie",
        "heiligheid",
        "heilig",
        "hulde",
        "homologie",
        "eerlijk",
        "eerlijkheid",
        "honing",
        "huwelijksreis",
        "eer",
        "eervol",
        "hoop",
        "hoopvol",
        "horizon",
        "gastvrijheid",
        "huishouden",
        "huishouden",
        "omhelzing",
        "humaan",
        "humanitaire",
        "de mensheid",
        "vernederd",
        "nederig",
        "nederigheid",
        "humorist",
        "humoristisch",
        "Hoera",
        "veeteelt",
        "stilte",
        "hut",
        "hygiënisch",
        "hymne",
        "idealisme",
        "afgod",
        "NO TRANSLATION",
        "verlichting",
        "illustreren",
        "illustere",
        "fantasierijke",
        "vlekkeloos",
        "onmetelijk",
        "onderdompelen",
        "onsterfelijk",
        "geven",
        "onpartijdig",
        "onpartijdigheid",
        "onberispelijk",
        "ondoordringbaar",
        "belang",
        "belangrijk",
        "indruk maken",
        "indruk",
        "verbeteren",
        "verbeterd",
        "verbetering",
        "verbeteren",
        "improviseren",
        "onvervreemdbaar",
        "inauguratie",
        "scherpzinnige",
        "omvatten",
        "ingesloten",
        "inclusief",
        "inclusief",
        "toename",
        "onuitwisbaar",
        "vergoeding",
        "onafhankelijkheid",
        "onverwoestbaar",
        "individualiteit",
        "ontembaar",
        "onuitsprekelijk",
        "goedkoop",
        "onfeilbaar",
        "zuigeling",
        "eindeloos",
        "oneindigheid",
        "invloedrijk",
        "informatie",
        "vernuftig",
        "erfenis",
        "onnavolgbaar",
        "onschuld",
        "onschuldig",
        "onschuldig",
        "onschadelijk",
        "innoveren",
        "innovatie",
        "inquirer",
        "onderzoek",
        "nieuwsgierig",
        "onafscheidelijk",
        "insigne",
        "inspecteur",
        "inspiratie",
        "inspireren",
        "geinspireerd",
        "instinctief",
        "instrueren",
        "instructie",
        "instructeur",
        "instrumentaal",
        "verzekeren",
        "intact",
        "integriteit",
        "intellect",
        "intellectueel",
        "intelligentie-",
        "intelligent",
        "voorgenomen",
        "gemeenschap",
        "interesseren",
        "geïnteresseerd",
        "interessant",
        "interieur",
        "tussenvonnis",
        "intermezzo",
        "intiem",
        "intonatie",
        "onverschrokken",
        "intuïtie",
        "intuïtief",
        "onveranderlijk",
        "vindingrijk",
        "uitvinder",
        "onderzoeken",
        "versterken",
        "uitnodiging",
        "nodig uit",
        "uitnodigend",
        "ijzer",
        "onherleidbaar",
        "onweerlegbaar",
        "pot",
        "jam",
        "NO TRANSLATION",
        "baan",
        "toetreden",
        "toegetreden",
        "grappenmaker",
        "grapje",
        "journalist",
        "reis",
        "joviaal",
        "vreugde",
        "blijde",
        "vreugdevol",
        "jubelend",
        "jubileum",
        "gerechtelijk",
        "oordeelkundig",
        "springen",
        "gerechtigheid",
        "gerechtvaardigd",
        "rechtvaardiging",
        "herinnering",
        "gezichtskring",
        "grondtoon",
        "hoeksteen",
        "soort",
        "vriendelijkheid",
        "verwanten",
        "koning",
        "kus",
        "katje",
        "handigheid",
        "ridder",
        "wetende",
        "kennis",
        "roem",
        "arbeid",
        "lam",
        "land-",
        "geland",
        "laser",
        "prijzenswaardig",
        "lach",
        "lachend",
        "gelach",
        "lancering",
        "laureaat",
        "laurier",
        "lauweren",
        "kwistig",
        "rechtmatig",
        "lood",
        "leider",
        "liga",
        "leren",
        "aan het leren",
        "lector",
        "speelruimte",
        "wettelijk",
        "gelegaliseerd",
        "legendarisch",
        "leesbaarheid",
        "leesbaar",
        "vrije tijd",
        "rustig",
        "lemma",
        "mild",
        "les",
        "beletterd",
        "niveau",
        "hefboomwerking",
        "bevrijden",
        "bevrijding",
        "vrijheid",
        "bibliotheek",
        "levensbloed",
        "vuurtoren",
        "leuk vinden",
        "linguïst",
        "leeuw",
        "lenig",
        "logisch",
        "lang leven",
        "heerschappij",
        "lief",
        "liefde",
        "heerlijk",
        "NO TRANSLATION",
        "minnaar",
        "liefhebbend",
        "loyaal",
        "loyaliteit",
        "geluk",
        "Lucky",
        "heerlijk",
        "glans",
        "glanzend",
        "weelderig",
        "luxueus",
        "luxe",
        "lier",
        "lyrisch",
        "magisch",
        "magneet",
        "magnetisme",
        "magnetiet",
        "pracht",
        "prachtig",
        "meisje",
        "hoofd",
        "steunpilaar",
        "majestueus",
        "majesteit",
        "groot",
        "meerderheid",
        "beheren",
        "beheer",
        "mandarijn-",
        "mannelijkheid",
        "gemanifesteerd",
        "mannelijk",
        "manna",
        "gemanierd",
        "manieren",
        "fabrikant",
        "maart",
        "gemarkeerd",
        "verkoopbaar",
        "markies",
        "huwelijk",
        "merg",
        "trouwen",
        "maarschalk",
        "wonder",
        "wonderbaar",
        "verbazend",
        "mannelijk",
        "massage",
        "meester",
        "meesterwerk",
        "meesterschap",
        "stuurman",
        "huwelijk",
        "matrone",
        "maximum",
        "burgemeester",
        "weide",
        "afgemeten",
        "medaille",
        "bemiddelen",
        "bemiddeling",
        "bemiddelaar",
        "medisch",
        "NO TRANSLATION",
        "middellandse Zee",
        "mengeling",
        "aandenken",
        "gedenkwaardig",
        "verstelwerk",
        "menstruatie",
        "mentor",
        "barmhartig",
        "genade",
        "samensmelten",
        "verdienste",
        "verdienstelijk",
        "vreugde",
        "vrolijk",
        "metropolitaans",
        "moed",
        "microscopie",
        "verloskunde",
        "machtig",
        "nabootsen",
        "indachtig",
        "mindfulness",
        "ministerie",
        "wonder",
        "wonderbaarlijk",
        "vrolijkheid",
        "missionaris",
        "model-",
        "matig",
        "moderator",
        "bescheiden",
        "bescheidenheid",
        "stuwkracht",
        "monetair",
        "geld",
        "monnik",
        "monument",
        "Moreel",
        "moraliteit",
        "moraal",
        "mortier",
        "moederschap",
        "motief",
        "beweegbaar",
        "verhuizer",
        "gespierd",
        "muziek-",
        "musical",
        "veranderlijk",
        "wederzijds",
        "dutje",
        "naturalist",
        "bevaarbaar",
        "netjes",
        "nectar",
        "naald-",
        "onderhandelen",
        "onderhandelaar",
        "buurman",
        "zenuw",
        "nestelen",
        "adel",
        "edele",
        "edelman",
        "voordracht",
        "normaliteit",
        "opvallend",
        "notabelen",
        "NO TRANSLATION",
        "begrip",
        "voeding",
        "getallen",
        "verpleegster",
        "kwekerij",
        "koesteren",
        "voedzaam",
        "eik",
        "oase",
        "eed",
        "gehoorzaamheid",
        "doelstelling",
        "bereidwillig",
        "observant",
        "verkrijgbaar",
        "voor de hand liggend",
        "bewoner",
        "bezetting",
        "bezetten",
        "aanbod",
        "officier",
        "compenseren",
        "zijtak",
        "alwetend",
        "openheid",
        "opera",
        "gunstig",
        "kans",
        "optimisme",
        "optimist",
        "keuze",
        "facultatief",
        "orakel",
        "oratie",
        "orkest",
        "verordend",
        "ordelijk",
        "ordening",
        "biologisch",
        "organisatie",
        "organiseren",
        "georganiseerd",
        "orgasme",
        "oorspronkelijkheid",
        "versierde",
        "overladen",
        "resultaat",
        "overtreffen",
        "buitenwaarts",
        "dolblij",
        "overweldigend",
        "eigendom",
        "grote Oceaan",
        "stootkussen",
        "vulling",
        "peddelen",
        "smakelijk",
        "lapmiddel",
        "wondermiddel",
        "zwier",
        "NO TRANSLATION",
        "paprika",
        "toonbeeld",
        "grootste belang",
        "Pardon",
        "afkomst",
        "pariëtale",
        "deelnemen",
        "deelname",
        "partner",
        "vennootschap",
        "passie",
        "hartstochtelijk",
        "tijdverdrijf",
        "pastoor",
        "gebakje",
        "weide",
        "octrooi",
        "geduld",
        "geduldig",
        "patriarchaal",
        "patroon",
        "beschermheerschap",
        "betalen",
        "vrede",
        "vredelievend",
        "vredig",
        "Pauw",
        "pikken",
        "eigenaardigheid",
        "stamboom",
        "weergaloos",
        "neiging",
        "waarnemen",
        "waarneembaar",
        "eeuwigdurend",
        "perfect",
        "perfectie",
        "performer",
        "perk",
        "toestemming",
        "eeuwigheid",
        "volharding",
        "aanhoudend",
        "knap",
        "toepasselijk",
        "farmaceutisch",
        "filantroop",
        "filantropie",
        "filosoof",
        "Feniks",
        "fonetisch",
        "arts",
        "fysica",
        "fysiologie",
        "lichaamsbouw",
        "plukken",
        "picknick",
        "pittoreske",
        "vroomheid",
        "pil",
        "hoofdkussen",
        "piloot",
        "hoogtepunt",
        "pionier",
        "vroom",
        "merg",
        "spil",
        "kalm",
        "planning",
        "speels",
        "speelplaats",
        "schouwburg",
        "aangenaam",
        "verheugd",
        "plezierig",
        "belofte",
        "volkomen",
        "overvloedig",
        "plexus",
        "Pruim",
        "schietlood",
        "pluche",
        "vouw",
        "opvallend",
        "Politie",
        "politieagent",
        "Pools",
        "gepolijst",
        "beleefd",
        "beleefdheid",
        "NO TRANSLATION",
        "zwembad",
        "paus",
        "populariteit",
        "gepopulariseerd",
        "bevolking",
        "portable",
        "bezitten",
        "drinkbaar",
        "sterkte",
        "krachtig",
        "krachtig",
        "praktijk",
        "beoefend",
        "praktijk",
        "lof",
        "geprezen",
        "lofwaardig",
        "bidden",
        "voorzorgsmaatregel",
        "voorafgaan",
        "voorrang",
        "kostbaar",
        "nauwkeurig",
        "precisie",
        "voorliefde",
        "overheersend",
        "bij uitstek",
        "verkiezen",
        "premier",
        "pand",
        "bereiden",
        "bereid",
        "vooruitziend",
        "aanwezigheid",
        "aanwezig",
        "toonbaar",
        "conserverend",
        "behouden",
        "president",
        "prestige",
        "presto",
        "mooi",
        "zegevieren",
        "het voorkomen",
        "onschatbaar",
        "trots",
        "priester",
        "priesterschap",
        "priesterlijk",
        "voorrang",
        "primair",
        "eerste",
        "grondverf",
        "prins",
        "prinselijk",
        "prinses",
        "principaal",
        "ongerept",
        "bevoorrecht",
        "eerlijkheid",
        "procedure",
        "processie",
        "Proctor",
        "schaffen",
        "wonderbaarlijk",
        "wonderkind",
        "producent",
        "producerende",
        "productie",
        "produktief",
        "produktiviteit",
        "beroep",
        "professioneel",
        "professor",
        "bekwaamheid",
        "bedreven",
        "overvloedig",
        "vooruitgang",
        "progressie",
        "progressief",
        "vruchtbaar",
        "uitsteeksel",
        "prominent",
        "belofte",
        "veelbelovend",
        "bevordering",
        "stutten",
        "gepast",
        "profeet",
        "profylactische",
        "voorstel",
        "vooruitzicht",
        "gedijen",
        "welvaart",
        "welvarend",
        "beschermen",
        "bescherming",
        "beschermend",
        "beschermer",
        "trots",
        "bewijzen",
        "spreekwoordelijk",
        "voorzien",
        "het verstrekken van",
        "voorzichtigheid",
        "voorzichtig",
        "psalm",
        "openbaar",
        "Trekken",
        "preekstoel",
        "stipt",
        "nauwgezetheid",
        "puppy",
        "puur",
        "zuivering",
        "zuiveren",
        "taalzuiveraar",
        "puurheid",
        "snorren",
        "vreemd",
        "gekwalificeerd",
        "in aanmerking komende",
        "zoektocht",
        "vraag",
        "levendigheid",
        "rustig",
        "rustig",
        "kinine",
        "glans",
        "stralend",
        "Uitstralen",
        "radio-",
        "verrukt",
        "vervoering",
        "rationeel",
        "lezer",
        "gemakkelijk",
        "gereedheid",
        "lezing",
        "herbevestigen",
        "echt",
        "reden",
        "geruststelling",
        "geruststellen",
        "korting",
        "omwerking",
        "ontvangen",
        "ontvangende",
        "NO TRANSLATION",
        "vergelden",
        "drooglegging",
        "achteroverleunen",
        "herkenbaar",
        "adviseren",
        "verzoening",
        "heroverweging",
        "reconstrueren",
        "wederopbouw",
        "opnemer",
        "vergoeden",
        "herstel",
        "recreatie",
        "ontspannings-",
        "rectificeren",
        "verlossing",
        "verhaal",
        "verfijnen",
        "raffinage",
        "hervorming",
        "hervorming",
        "hervormer",
        "verfrissend",
        "renoveren",
        "vorstelijk",
        "regentes",
        "regelmatigheid",
        "reguleren",
        "rehabiliteren",
        "rehabilitatie",
        "vergoeden",
        "vergoeding",
        "versterking",
        "herstellen",
        "verheugen",
        "vreugdebetoon",
        "verjongen",
        "verjongd",
        "ontspanning",
        "relevant",
        "betrouwbaarheid",
        "betrouwbaar",
        "vertrouwen",
        "reliëf",
        "verlichten",
        "nieuwe versie",
        "opmerkelijk",
        "NO TRANSLATION",
        "remedie",
        "kwijtschelding",
        "vervormen",
        "Renaissance",
        "geven",
        "vernieuwing",
        "vernieuwen",
        "vernieuwing",
        "roem",
        "vermaard",
        "reorganiseren",
        "reparatie",
        "terugbetalen",
        "berouwen",
        "bijvullen",
        "vol",
        "verslaggever",
        "rust",
        "vertegenwoordigd",
        "voortplantings-",
        "achtenswaardig",
        "redden",
        "reserveren",
        "inwoner",
        "veerkrachtig",
        "resistief",
        "resoluut",
        "middelen",
        "eerbied",
        "eerbiedwaardigheid",
        "achtenswaardig",
        "eerbiedig",
        "met inachtneming van",
        "opzichten",
        "uitstel",
        "luisterrijk",
        "verantwoordelijk",
        "sympathiek",
        "rust uit",
        "rustgevend",
        "teruggave",
        "versterkend middel",
        "herstellen",
        "terughoudendheid",
        "hervatting",
        "behoud",
        "bijeenkomst",
        "zwelgen",
        "zwelgt",
        "Revere",
        "eerbied",
        "reverend",
        "mijmering",
        "Herzien",
        "herleving",
        "revolutionair",
        "beloning",
        "ritme",
        "ritmische",
        "lint",
        "rijkheid",
        "rijder",
        "rechtvaardig",
        "rechtmatig",
        "terecht",
        "rijp",
        "rijpen",
        "stijgende lijn",
        "klinken",
        "roadster",
        "robuust",
        "rots",
        "hengel",
        "prettig",
        "romance",
        "romantisch",
        "romantiek",
        "ravotten",
        "ingeworteld",
        "rooskleurig",
        "rota",
        "routine-",
        "royalty",
        "rubriek",
        "Ruth",
        "veilig",
        "vrijwaren",
        "salie",
        "heilige",
        "vroom",
        "salaris",
        "saillant",
        "heilzaam",
        "groet",
        "redding",
        "zalf",
        "samoerai",
        "heiliging",
        "heiligen",
        "heiligdom",
        "optimistisch",
        "sanitair",
        "satijn",
        "bevredigend",
        "tevreden",
        "opslaan",
        "spaargeld",
        "genieten",
        "hartig",
        "savvy",
        "geleerde",
        "beurs",
        "wetenschappelijk",
        "wetenschapper",
        "NO TRANSLATION",
        "partituur",
        "schriftgeleerde",
        "script",
        "verrukkelijk",
        "beeldhouwwerk",
        "zee",
        "zegel",
        "gekruid",
        "secretariaat",
        "anciënniteit",
        "sensationeel",
        "zin",
        "gevoeligheid",
        "verstandig",
        "sensualiteit",
        "sensueel",
        "sentimenteel",
        "sentimentaliteit",
        "schildwacht",
        "kalmte",
        "preek",
        "serum",
        "settlor",
        "seks",
        "vorm",
        "goed gevormd",
        "delen",
        "schuilplaats",
        "herder",
        "schijnen",
        "schijnend",
        "boodschappen doen",
        "schouder",
        "schrander",
        "zijde",
        "makkelijker maken",
        "oprecht",
        "oprechtheid",
        "zingen",
        "afzonderlijk",
        "mijnheer",
        "zusterschap",
        "geschoold",
        "behendig",
        "hemel",
        "leisteen",
        "glad",
        "slank",
        "slank",
        "glimlach",
        "glimlachen",
        "getroffen",
        "gladheid",
        "gehinnik",
        "soberheid",
        "sociaal",
        "troost",
        "soldaat",
        "solide",
        "stevigheid",
        "oplossing",
        "solvabiliteit",
        "sonar",
        "sonate",
        "sonnet",
        "sonoor",
        "kalmeren",
        "verzachtend",
        "NO TRANSLATION",
        "soliditeit",
        "soep",
        "spa",
        "ruim",
        "spaniel",
        "fonkeling",
        "speciaal",
        "NO TRANSLATION",
        "toespraak",
        "snel",
        "spelling",
        "kruid",
        "geest",
        "spiritualiën",
        "geweldig",
        "pracht",
        "sponsor",
        "vlekkeloos",
        "echtgenoot",
        "net",
        "stal",
        "staccato",
        "roestvrij",
        "hengst",
        "stoer",
        "uithoudingsvermogen",
        "staand",
        "ster",
        "sterrenlicht",
        "sterrenhemel",
        "statig",
        "uitspraak",
        "standbeeld",
        "staat",
        "trouw",
        "standvastig",
        "stellaire",
        "rentmeester",
        "stilte",
        "op te slaan",
        "rechtdoorzee",
        "strategisch",
        "strateeg",
        "kracht",
        "versterken",
        "versterking",
        "opvallend",
        "opvallend",
        "sterk",
        "structuur",
        "knop",
        "studie",
        "robuust",
        "sublimering",
        "stof",
        "substantief",
        "slagen",
        "slagen",
        "succes",
        "geslaagd",
        "bondig",
        "voldoende hoeveelheid",
        "suiker",
        "geschikt",
        "zwoel",
        "zon",
        "zonnig",
        "zonsondergang",
        "zonneschijn",
        "prachtig",
        "bovenmenselijk",
        "beter",
        "superioriteit",
        "superman",
        "superster",
        "smeekbede",
        "benodigdheden",
        "levering",
        "ondersteunde",
        "supporter",
        "ondersteunen",
        "opperst",
        "uiterst",
        "borgtocht",
        "vermoeden",
        "overtreffen",
        "verrassing",
        "landmeetkundige",
        "overleven",
        "zweer",
        "zoet",
        "geliefde",
        "geliefde",
        "zoetheid",
        "snoepgoed",
        "snel",
        "zwemmen",
        "symbolisch",
        "symmetrisch",
        "symmetrie",
        "sympathiek",
        "sympathie",
        "symfonie",
        "synchroniseren",
        "synergetische",
        "synode",
        "tact",
        "verhaal",
        "talent",
        "talisman",
        "praten",
        "gelooide",
        "taak",
        "smaakvol",
        "lekker",
        "onderwijzen",
        "leraar",
        "technologie",
        "matigheid",
        "gehumeurd",
        "houdbaar",
        "vasthoudend",
        "vasthoudendheid",
        "pacht",
        "huurder",
        "inschrijving",
        "tederheid",
        "dankbaar",
        "dankzegging",
        "theoretisch",
        "therapeutische",
        "therapie",
        "NO TRANSLATION",
        "volbloed",
        "nadenkend",
        "bedachtzaamheid",
        "spaarzaamheid",
        "sensatie",
        "opwindend",
        "bloeiende",
        "troon",
        "kietelen",
        "tegels",
        "tijdig",
        "klatergoud",
        "titel",
        "geroosterd brood",
        "verdraagzaam",
        "tolerantie",
        "top",
        "taaiheid",
        "toren",
        "torenhoge",
        "traditioneel",
        "rustig",
        "kalmte",
        "transcendentie",
        "transcendentaal",
        "op reis",
        "schat",
        "boom",
        "enorm",
        "neiging",
        "modieus",
        "zijrivier",
        "schatting",
        "remschoen",
        "triomf",
        "triomfantelijk",
        "trofee",
        "wapenstilstand",
        "True",
        "betrouwbaar",
        "waarheid",
        "waarachtigheid",
        "voogdij",
        "leermeester",
        "tweeling",
        "twinkelen",
        "tenslotte",
        "scheidsrechter",
        "eenstemmigheid",
        "unaniem",
        "bescheiden",
        "onpartijdige",
        "onbreekbaar",
        "ongebroken",
        "ongedwongen",
        "onderstrepen",
        "begrip",
        "assureren",
        "onverdeeld",
        "overgankelijk",
        "ondubbelzinnig",
        "ontvouwen",
        "unificatie",
        "gelijkmatig",
        "ongeïnfecteerde",
        "uniek",
        "harmonie",
        "unitaire",
        "verenigd",
        "eenheid",
        "Universiteit",
        "onbeperkt",
        "bescheiden",
        "onbetwistbaar",
        "onbetwistbaar",
        "onbetwist",
        "ongedeerd",
        "onzelfzuchtig",
        "onovertroffen",
        "onwrikbaar",
        "verheffen",
        "rechtop",
        "bruikbaarheid",
        "deurwaarder",
        "gebruikelijk",
        "nut",
        "utopisch",
        "vakantie",
        "vaccin",
        "dapper",
        "NO TRANSLATION",
        "waardevol",
        "voorhoede",
        "overwinnen",
        "fluweel",
        "fluweelachtig",
        "eerbiedwaardig",
        "verering",
        "waarheidsgetrouwheid",
        "groen",
        "verificatie",
        "geverifieerd",
        "voorwaar",
        "echt",
        "lente-",
        "sappigheid",
        "veteraan",
        "vicaris",
        "Victor",
        "zegevierend",
        "zege",
        "waakzaamheid",
        "waakzaam",
        "kracht",
        "krachtig",
        "dorpeling",
        "gerechtvaardigd",
        "rechtvaardiging",
        "Maagd",
        "maagdelijkheid",
        "deugd",
        "deugdzaam",
        "visie",
        "visionaire",
        "bezoek",
        "bezoeker",
        "vitaal",
        "vitaliteit",
        "levendig",
        "levendig",
        "woordenschat",
        "vrijwilliger",
        "wellustig",
        "getuigen",
        "gelofte",
        "loon",
        "garantie",
        "krijger",
        "waakhond",
        "waakzaam",
        "wachter",
        "waterbestendig",
        "rijkdom",
        "weerbestendig",
        "verwelkomd",
        "wit",
        "witheid",
        "gezond",
        "hekje",
        "wijd verspreid",
        "gaarne",
        "bereidwilligheid",
        "meervallertje",
        "winnaar",
        "winnend",
        "winst",
        "draadloze",
        "wis",
        "wijsheid",
        "wijs",
        "verstand",
        "weerstaan",
        "verstand",
        "geestig",
        "tovenaar",
        "baarmoeder",
        "prachtig",
        "wonderlijk",
        "verwonderlijk",
        "woord",
        "werkend",
        "aanbidden",
        "waard",
        "waardig",
        "wot",
        "auteur",
        "jong",
        "jonger",
        "jeugd",
        "ijver",
        "ijverig",
        "smaak",
    ]
)

_negative = set(
    [
        "in de steek laten",
        "verlaten",
        "verlatenheid",
        "ontvoering",
        "afwijkend",
        "aberratie",
        "verafschuwen",
        "weerzinwekkend",
        "verachtelijk",
        "abnormaal",
        "afschaffen",
        "afschaffing",
        "afschuwelijk",
        "gruwel",
        "afbreken",
        "abortus",
        "vruchteloos",
        "schuring",
        "afschaffen",
        "abces",
        "afwezigheid",
        "afwezig",
        "afwezige",
        "absenteïsme",
        "absurd",
        "absurditeit",
        "misbruik",
        "onpeilbaar",
        "afgrond",
        "ongeval",
        "onopzettelijk",
        "vervloekt",
        "beschuldiging",
        "accusatief",
        "verdachte",
        "aanklager",
        "beschuldigen",
        "pijn",
        "pijnlijke",
        "zuur",
        "actiegericht",
        "adder",
        "verslaving",
        "vet",
        "berechten",
        "vermaning",
        "drijvend",
        "vervalste",
        "overspel",
        "tegenstander",
        "nadelige",
        "tegenslag",
        "teisteren",
        "geteisterd",
        "bezoeking",
        "belediging",
        "bang",
        "nasleep",
        "nasmaak",
        "verergerd",
        "verzwarend",
        "verergering",
        "agressie",
        "agressief",
        "agressor",
        "ontzet",
        "opgewonden",
        "agitatie",
        "pijnlijke",
        "doodsangst",
        "aan de grond",
        "ail",
        "ziekelijk",
        "doelloos",
        "airs",
        "alarm",
        "zorgwekkend",
        "alcoholisme",
        "vreemdeling",
        "vervreemden",
        "vervreemd",
        "vervreemding",
        "alimentatie",
        "bewering",
        "beweren",
        "afzijdig",
        "woordenwisseling",
        "dubbelzinnig",
        "hinderlaag",
        "geheugenverlies",
        "amfetaminen",
        "anaconda",
        "anaal",
        "anarchisme",
        "anarchist",
        "anarchie",
        "anathema",
        "oude",
        "boosheid",
        "angina",
        "hengelen",
        "boos",
        "angst",
        "vijandigheid",
        "animositeit",
        "vernietigen",
        "vernietigd",
        "vernietiging",
        "ergeren",
        "ergernis",
        "vervelend",
        "vernietigen",
        "vernietiging",
        "afwijking",
        "anoniem",
        "antagonisme",
        "antagonist",
        "vijandig",
        "miltvuur",
        "antichrist",
        "antipathie",
        "verouderd",
        "antisociaal",
        "tegenstelling",
        "angst",
        "angstig",
        "apache",
        "apathisch",
        "apathie",
        "bladluis",
        "verschrikkelijk",
        "appendicitis",
        "vrees",
        "beducht",
        "toeëigening",
        "verouderd",
        "zwaar",
        "argumenteren",
        "argument",
        "betogend",
        "dor",
        "bewapening",
        "aanklacht",
        "achterstand",
        "arresteren",
        "arrogantie",
        "arrogant",
        "arseen-",
        "brandstichting",
        "artillerie",
        "as",
        "beschaamd",
        "as",
        "ezel",
        "aanranden",
        "aanvaller",
        "moordenaar",
        "vermoorden",
        "moord",
        "aanval",
        "lul",
        "op een dwaalspoor",
        "samentrekkend",
        "asiel",
        "atheïsme",
        "atherosclerose",
        "afgrijselijk",
        "gruweldaad",
        "atrofie",
        "aanval",
        "aanvallende",
        "verzwakt",
        "verzwakking",
        "vermetelheid",
        "sober",
        "strengheid",
        "autocratisch",
        "lijkschouwing",
        "lawine",
        "gierigheid",
        "wreker",
        "afkerig",
        "afkeer",
        "vermijden",
        "vermijding",
        "afschuwelijk",
        "onhandigheid",
        "scheef",
        "gebabbel",
        "kabbelende",
        "baviaan",
        "achterwaarts",
        "achteruit",
        "opstuwing",
        "bacterie",
        "NO TRANSLATION",
        "slecht",
        "das",
        "slecht",
        "slechtheid",
        "deurwaarder",
        "aas",
        "baal",
        "balk",
        "NO TRANSLATION",
        "bandiet",
        "verderf",
        "knal",
        "worstje",
        "verbannen",
        "verbannen",
        "verbanning",
        "bankroet",
        "faillissement",
        "banshee",
        "weerhaak",
        "barbaar",
        "barbaars",
        "barbaarsheid",
        "schors",
        "verjaard",
        "dor",
        "barricade",
        "barrière",
        "ongegrond",
        "bastaard-",
        "beslag",
        "gehavend",
        "accu",
        "strijd",
        "vochten",
        "slagveld",
        "liederlijk",
        "bajonet",
        "toonder",
        "beest",
        "beestachtig",
        "pak slaag",
        "overkomen",
        "bedelen",
        "bedelaar",
        "bedelarij",
        "nijlpaard",
        "verplicht",
        "verlate",
        "kleineren",
        "strijdlustig",
        "riem",
        "nijptang",
        "diep bedroefd",
        "sterfgeval",
        "beroofd",
        "gek",
        "beestachtig",
        "verraden",
        "verraad",
        "pas op",
        "verbijsterd",
        "vooroordeel",
        "vooringenomen",
        "gekibbel",
        "NO TRANSLATION",
        "onverdraaglijke",
        "kwezelachtig",
        "gal",
        "biopsie",
        "berk",
        "geboorteplaats",
        "teef",
        "beet",
        "bitter",
        "bitterheid",
        "bizar",
        "zwart",
        "ploertendoder",
        "chantage",
        "zwartheid",
        "de schuld geven",
        "zacht",
        "godslasterlijk",
        "godslastering",
        "ontploffing",
        "schreeuwerig",
        "kletsen",
        "bles",
        "guur",
        "bloeden",
        "smet",
        "meeldauw",
        "ellendig",
        "Blind",
        "verblind",
        "blindelings",
        "blindheid",
        "blaar",
        "opgeblazen",
        "bobbel",
        "blokkade",
        "bloedvergieten",
        "bloeddorstig",
        "bloedig",
        "vlek",
        "blazer",
        "uitblazen",
        "blues",
        "bluffen",
        "flater",
        "vervagen",
        "wazig",
        "blozen",
        "opscheppen",
        "moeras",
        "vals",
        "koken",
        "standaardtekst",
        "bom",
        "bombarderen",
        "bombardement",
        "gebombardeerd",
        "slavernij",
        "obligaties",
        "boe",
        "domoor",
        "drank",
        "NO TRANSLATION",
        "verveling",
        "saai",
        "lener",
        "dwars zitten",
        "dwars",
        "bodem",
        "gebonden",
        "aanval",
        "rund",
        "jongen",
        "boycot",
        "opscheppen",
        "brandewijn",
        "bravade",
        "ruzie",
        "bronzen",
        "schending",
        "afbreken",
        "halsbrekend",
        "NO TRANSLATION",
        "steekpenning",
        "omkoperij",
        "brigade",
        "zwavel",
        "borstel",
        "volle laag",
        "braden",
        "kapot gegaan",
        "gebroken",
        "bordeel",
        "blauwe plek",
        "dupe",
        "brutaal",
        "beestachtigheid",
        "bruut",
        "buffet",
        "kever",
        "NO TRANSLATION",
        "knolvormig",
        "bullebak",
        "kont",
        "jammer",
        "zwaar",
        "bureaucratie",
        "bureaucraat",
        "inbreker",
        "inbraak",
        "begrafenis",
        "begraven",
        "Burke",
        "verbrand",
        "opgepakt",
        "slager",
        "mikpunt",
        "gonsde",
        "kliek",
        "cacofonie",
        "ploert",
        "kadaver",
        "kooi",
        "berekenen",
        "NO TRANSLATION",
        "calls",
        "campagne voeren",
        "Annuleer",
        "kanker",
        "kanker",
        "kannibaal",
        "kannibalisme",
        "NO TRANSLATION",
        "gevangen",
        "gevangenschap",
        "vanger",
        "gevangen nemen",
        "karkas",
        "carcinoom",
        "cardiomyopathie",
        "slordigheid",
        "karikatuur",
        "cariës",
        "bloedbad",
        "vleselijk",
        "vleesetend",
        "kartel",
        "geval",
        "kistje",
        "kaste",
        "ongeval",
        "staar",
        "catastrofe",
        "katheter",
        "voorzichtigheid",
        "afstaan",
        "begraafplaats",
        "censor",
        "afkeuring",
        "Cess",
        "het ophouden",
        "kaf",
        "schuren",
        "verdriet",
        "uitdaging",
        "chaos",
        "chaotisch",
        "charade",
        "laste",
        "jacht",
        "kastijding",
        "spraakzaam",
        "goedkoop",
        "bedriegen",
        "kwarktaart",
        "chicane",
        "kinderachtig",
        "koud",
        "chloroform",
        "stikken",
        "cholera",
        "karbonade",
        "karwei",
        "chronisch",
        "sigaret",
        "geschreeuw",
        "botsen",
        "botsende",
        "klauw",
        "klooster",
        "bewolkt",
        "bewolking",
        "klomp",
        "onhandig",
        "cocaïne",
        "dwingen",
        "dwang",
        "kist",
        "koude",
        "koud",
        "koude",
        "koliek",
        "ineenstorting",
        "botsing",
        "geheime verstandhouding",
        "coma",
        "comateuze",
        "gevecht",
        "strijder",
        "strijdlustig",
        "toewijzing",
        "commotie",
        "communisme",
        "communist",
        "wedstrijd",
        "klagen",
        "klacht",
        "gecomplexeerde",
        "ingewikkeldheid",
        "compliceren",
        "ingewikkeld",
        "complicatie",
        "compost",
        "dwang",
        "verplicht",
        "verbergen",
        "verborgen",
        "verborgenheid",
        "verwaandheid",
        "verwaand",
        "hersenschudding",
        "veroordelen",
        "veroordeling",
        "minzaam",
        "genadigheid",
        "bekentenis",
        "beperken",
        "beperkt",
        "opsluiting",
        "confisqueren",
        "confiscatie",
        "vuurzee",
        "conflict",
        "tegenstrijdig",
        "verwarren",
        "beschaamd",
        "verwarren",
        "verwarring",
        "congestie",
        "goochelen",
        "verovering",
        "samenzweerder",
        "samenzweren",
        "consternatie",
        "constipatie",
        "beperken",
        "gedwongen",
        "beperking",
        "besmetting",
        "besmettelijk",
        "besmetten",
        "vervuild",
        "besmetting",
        "minachting",
        "verachtelijk",
        "minachtend",
        "omstreden",
        "smokkelwaar",
        "gecontracteerd",
        "tegenspreken",
        "tegenstrijdigheid",
        "tegenstrijdig",
        "tegendeel",
        "gecontrasteerd",
        "overtreden",
        "overtreding",
        "controversieel",
        "controverse",
        "veroordelen",
        "overtuiging",
        "kippenren",
        "kopiëren",
        "copycat",
        "lijkschouwer",
        "korporaal",
        "lijk",
        "correctie",
        "corrosie",
        "bijtend",
        "corrupt",
        "corrumperende",
        "corruptie",
        "hoesten",
        "raadgever",
        "lange jacht",
        "begeren",
        "lafaard",
        "lafheid",
        "laf",
        "prikkelbaar",
        "barst",
        "gebarsten",
        "kraken",
        "kramp",
        "krap",
        "zwengel",
        "humeurig",
        "onzin",
        "neerstorten",
        "kruipen",
        "krankzinnige",
        "gek",
        "krakende",
        "schepsel",
        "kruipen",
        "misdrijf",
        "crimineel",
        "criminaliteit",
        "ineenkrimpen",
        "verlamde",
        "verminkt",
        "crisis",
        "knapperig",
        "criticus",
        "kritiek",
        "bekritiseren",
        "oplichter",
        "kruis",
        "hurken",
        "kruisband",
        "kruisiging",
        "ruw",
        "wreed",
        "wreed",
        "wreedheid",
        "afbrokkelende",
        "kraken",
        "kruistocht",
        "verpletterd",
        "breken",
        "korstig",
        "huilen",
        "huilen",
        "crypt",
        "hoorndrager",
        "koekoek",
        "ruiming",
        "schuldigheid",
        "schuldig",
        "dader",
        "cultus",
        "hinderlijk",
        "cupping",
        "cur",
        "vloek",
        "vervloekt",
        "gevloek",
        "vluchtig",
        "snijder",
        "moordenaar",
        "snijdend",
        "cyanide",
        "cycloon",
        "cyste",
        "cytomegalovirus",
        "ploeteren",
        "demon",
        "gek",
        "dolk",
        "schade",
        "schadevergoeding",
        "vloek",
        "verdoemenis",
        "verdoemde",
        "demper",
        "roos",
        "dandy",
        "Gevaar",
        "gevaarlijk",
        "verduisteren",
        "verduisterd",
        "duisternis",
        "gestippelde",
        "lafhartig",
        "versuft",
        "deactiveren",
        "impasse",
        "dodelijk",
        "doof",
        "dood",
        "debacle",
        "losbandigheid",
        "puin",
        "schuld",
        "schuldenaar",
        "verval",
        "vervald",
        "overleden",
        "bedrog",
        "bedrieglijk",
        "misleiden",
        "bedrogen",
        "bedriegen",
        "bedrog",
        "bedrieglijk",
        "declinatie",
        "afwijzen",
        "afnemende",
        "ontleding",
        "kleiner worden",
        "decrement",
        "afgeleefd",
        "afkeuren",
        "aftrekken",
        "laster",
        "lasterlijk",
        "standaard",
        "nederlaag",
        "verslagen",
        "defect",
        "NO TRANSLATION",
        "defecte",
        "weerloos",
        "uitstel",
        "tarting",
        "uitdagend",
        "tekort",
        "tekort",
        "deflatie veroorzaken",
        "deflatie",
        "vervormen",
        "misvormd",
        "mismaaktheid",
        "bedriegen",
        "overledene",
        "trotseren",
        "degeneratie",
        "ontaarden",
        "vermindering",
        "degraderen",
        "onterende",
        "vertraging",
        "vertraagd",
        "schadelijk",
        "verwijdering",
        "delinquentie",
        "delinquent",
        "ijlend",
        "delirium",
        "zondvloed",
        "waan",
        "waanvoorstellingen",
        "vraag naar",
        "veeleisende",
        "krankzinnig",
        "zwakzinnigheid",
        "overlijden",
        "slopen",
        "sloop",
        "demon",
        "demonisch",
        "gedemoraliseerd",
        "ontkenning",
        "ontkend",
        "opzeggen",
        "aanklacht",
        "ontkennen",
        "ontkennen",
        "overleden",
        "vertrek",
        "afhankelijkheid",
        "afhankelijkheid",
        "betreurenswaardig",
        "betreuren",
        "deporteren",
        "deportatie",
        "verdorven",
        "verdorvenheid",
        "depreciëren",
        "afgeschreven",
        "waardevermindering",
        "deprimeren",
        "terneergeslagen",
        "deprimerend",
        "depressie",
        "depressieve",
        "beroving",
        "zinneloos",
        "verlaten",
        "spot",
        "afbreuk",
        "denigrerende",
        "ontheiliging",
        "woestijn",
        "uitgestorven",
        "desertie",
        "ophouden",
        "verwoesting",
        "wanhoop",
        "wanhopig",
        "ten einde raad",
        "verachtelijk",
        "NO TRANSLATION",
        "despotisch",
        "despotisme",
        "ontbloot",
        "vernietigd",
        "torpedojager",
        "vernietigen",
        "verwoesting",
        "vernietigend",
        "detachement",
        "detineren",
        "gedetineerde",
        "hechtenis",
        "achteruitgaan",
        "verslechterd",
        "verslechtering",
        "verafschuwen",
        "ontploffen",
        "afbreuk doen aan",
        "schade",
        "schadelijk",
        "detritus",
        "verwoesten",
        "verwoestende",
        "verwoesting",
        "duivel",
        "duivels",
        "omslachtig",
        "devolutie",
        "verslinden",
        "duivels",
        "diagnose",
        "schimprede",
        "dictator",
        "dictatoriaal",
        "dictatuur",
        "NO TRANSLATION",
        "moeilijkheden",
        "moeilijkheid",
        "afdwalen",
        "vervallen",
        "verdund",
        "verminderen",
        "verminderde",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "vuil",
        "vuil",
        "onbekwaamheid",
        "onbruikbaar maken",
        "invalide",
        "ontevreden",
        "het oneens zijn",
        "oneens",
        "meningsverschil",
        "afgekeurd",
        "teleurstellen",
        "teleurgesteld",
        "teleurstellend",
        "teleurstelling",
        "afkeuring",
        "afkeuren",
        "afgekeurd",
        "afkeurend",
        "ramp",
        "noodlottig",
        "niet geloven",
        "teruggooi",
        "ontlading",
        "discipline",
        "afwijzen",
        "verkleuring",
        "verkleurde",
        "ongemak",
        "Loskoppelen",
        "losgekoppeld",
        "ontkoppeling",
        "ontevredenheid",
        "staken",
        "discontinuïteit",
        "onenigheid",
        "ontmoedigen",
        "ontmoediging",
        "diskrediet",
        "onderscheiden",
        "onderscheid",
        "discriminatie",
        "minachting",
        "ziekte",
        "ziek",
        "losgemaakt",
        "ontkoppeling",
        "bedorven",
        "schande",
        "NO TRANSLATION",
        "schandelijk",
        "ontevreden",
        "walg",
        "walgelijk",
        "ontmoedigd",
        "ontmoedigend",
        "oneerlijk",
        "oneerlijkheid",
        "onteren",
        "ontgoocheling",
        "disinformatie",
        "onoprecht",
        "uit elkaar vallen",
        "ontbinding",
        "belangeloos",
        "afkeer",
        "hekel",
        "uit de kom",
        "somber",
        "ontzetting",
        "verbrokkeling",
        "ontslag",
        "ongehoorzaamheid",
        "ongehoorzaam",
        "niet gehoorzamen",
        "wanorde",
        "wanordelijk",
        "ongeorganiseerd",
        "geringschatten",
        "minachtend",
        "ongelijkheid",
        "kalm",
        "verdrijven",
        "spreiding",
        "verdringen",
        "niet tevreden",
        "misnoegen",
        "beschikking",
        "onteigend",
        "geschil",
        "diskwalificatie",
        "gediskwalificeerd",
        "diskwalificeren",
        "buiten beschouwing laten",
        "buiten beschouwing",
        "berucht",
        "oneerbiedigheid",
        "oneerbiedig",
        "ontwrichting",
        "ontevredenheid",
        "tweedracht",
        "dissenting",
        "ondienst",
        "dissident",
        "ontbinding",
        "dissonant",
        "afkeer",
        "onsmakelijk",
        "vervormd",
        "vervorming",
        "afleiden",
        "afgeleid",
        "afleidende",
        "afleiding",
        "radeloos",
        "nood",
        "distressed",
        "schrijnende",
        "wantrouwen",
        "verstoring",
        "verstoord",
        "onbruik",
        "onbruik geraakte",
        "afwijkend",
        "afgestoten",
        "desinvestering",
        "scheiden",
        "duizeligheid",
        "duizelig",
        "aangemeerd",
        "NO TRANSLATION",
        "doldrums",
        "uitkering",
        "NO TRANSLATION",
        "dominant",
        "overheersing",
        "ezel",
        "tekening",
        "noodlot",
        "verdoemde",
        "dag des oordeels",
        "twijfel",
        "twijfelachtig",
        "twijfelende",
        "douche",
        "streng",
        "val",
        "saai",
        "riolering",
        "nadeel",
        "vrezen",
        "vreselijk",
        "vreselijk",
        "somber",
        "drinken",
        "gewauwel",
        "dar",
        "hangende",
        "droogte",
        "verdrinken",
        "slaperigheid",
        "gezwoeg",
        "dronken",
        "dronkenschap",
        "twijfelachtig",
        "dof",
        "stom",
        "pop",
        "stortplaatsen",
        "manen",
        "kerker",
        "dupe",
        "dubbelhartigheid",
        "dwang",
        "stof",
        "dwarfed",
        "stervende",
        "dysenterie",
        "aardbeving",
        "afluisteren",
        "edict",
        "verwijfd",
        "egoïstische",
        "flagrante",
        "uitwerpen",
        "uitwerping",
        "eliminatie",
        "ontwijkend",
        "uitgehongerd",
        "NO TRANSLATION",
        "in verlegenheid brengen",
        "gênant",
        "verlegenheid",
        "verduistering",
        "embolie",
        "verwikkeld",
        "noodgeval",
        "enclave",
        "inbreuk",
        "last",
        "in gevaar brengen",
        "bedreigde",
        "endemisch",
        "vijand",
        "handhaving",
        "raadselachtig",
        "vijandschap",
        "tot slaaf maken",
        "geknecht",
        "knechting",
        "verward",
        "verstrikking",
        "ingewanden",
        "jaloers",
        "epidemie",
        "epilepsie",
        "uitroeien",
        "uitroeiing",
        "wissen",
        "erosie",
        "dwalen",
        "dwalend",
        "grillige",
        "drukfout",
        "foutief",
        "fout",
        "uitbarsten",
        "uitbarsting",
        "uitbreiden",
        "schuwen",
        "spionage",
        "vervreemd",
        "euthanasia",
        "evacueren",
        "evacuatie",
        "ontwijken",
        "ontduiking",
        "uitzetten",
        "uitzetting",
        "onheil",
        "verscherpen",
        "exacerbatie",
        "veeleisend",
        "overdrijven",
        "overdreven",
        "examen",
        "ergernis",
        "uitgraving",
        "overmaat",
        "accijns",
        "uitgesloten",
        "Exclusief",
        "uitsluiting",
        "uitwerpsel",
        "ondraaglijk",
        "excuus",
        "executie",
        "beul",
        "uitlaat",
        "uitgeput",
        "uitputting",
        "NO TRANSLATION",
        "verbanning",
        "uitdrijving",
        "expatriate",
        "verdrijven",
        "uitgaven",
        "uitgaven",
        "vervallen",
        "niet meer geldig",
        "vloek",
        "ontploffen",
        "explosie",
        "ontplofbaar",
        "blootgesteld",
        "onteigening",
        "verdrijving",
        "uitroeien",
        "uitroeiing",
        "uitgestorven",
        "doven",
        "buitengerechtelijke",
        "uiteinde",
        "fabriceren",
        "verzinsel",
        "vervagen",
        "faeces",
        "tekortkoming",
        "mislukking",
        "flauwte",
        "trouweloos",
        "nep",
        "vallen",
        "misleidend",
        "bedrieglijkheid",
        "feilbaar",
        "vallend",
        "braak",
        "leugen",
        "vals",
        "vervalsing",
        "vervalsen",
        "valsheid",
        "wankelen",
        "hongersnood",
        "fanaticus",
        "klucht",
        "kluchtig",
        "vastend",
        "dik",
        "dodelijk",
        "fataliteit",
        "lot",
        "vermoeidheid",
        "vermoeid",
        "vet",
        "fout",
        "defect",
        "reekalf",
        "angst",
        "angstig",
        "vreselijk",
        "vrezend",
        "koortsig",
        "fecal",
        "ontlasting",
        "honorarium",
        "zwak",
        "gefingeerd",
        "viel",
        "misdadiger",
        "zware misdaad",
        "gisten",
        "woest",
        "wildheid",
        "vete",
        "feodaal",
        "leenstelsel",
        "koortsig",
        "fiasco",
        "jokken",
        "wispelturig",
        "gefingeerd",
        "duivel",
        "woest",
        "strijd",
        "vechten",
        "vrijbuiter",
        "vuiligheid",
        "vies",
        "vuurwapens",
        "past bij",
        "slap",
        "slap",
        "markeren",
        "flagrante",
        "vlok",
        "klep",
        "winderigheid",
        "pronken",
        "fout",
        "vlo",
        "NO TRANSLATION",
        "vacht",
        "vlezig",
        "terugdeinzen",
        "geselen",
        "plof",
        "bot",
        "griep",
        "schommeling",
        "vijand",
        "verijdeld",
        "dwaasheid",
        "dwaas",
        "dwaas",
        "dwaasheid",
        "voeder",
        "inval",
        "verbieden",
        "afschrikwekkend",
        "dwingen",
        "gedwongen",
        "gedwongen",
        "voorteken",
        "af te schermen",
        "afzien",
        "buitenlands",
        "buitenlander",
        "gewaarschuwd",
        "verbeuren",
        "verbeurd",
        "verbeuring",
        "namaak",
        "vergeten",
        "vergeten",
        "verlaten",
        "vormloos",
        "ontucht",
        "verlaten",
        "verlaten",
        "vals",
        "breuk",
        "breekbaar",
        "zwakheid",
        "krankzinnig",
        "bedrog",
        "frauduleus",
        "vol",
        "strijd",
        "rafelig",
        "grillig",
        "ijskoud",
        "razend",
        "waanzinnig",
        "razernij",
        "kniezen",
        "schrik",
        "verschrikken",
        "bang",
        "verschrikkelijk",
        "koud",
        "frivool",
        "bevrorenheid",
        "schuim",
        "frons",
        "fronsen",
        "vruchteloos",
        "frustreren",
        "gefrustreerd",
        "frustratie",
        "onzin",
        "vluchteling",
        "morrelen",
        "damp",
        "rokend",
        "paddestoel",
        "funk",
        "woedend",
        "furore",
        "woede",
        "ophef",
        "kieskeurig",
        "vergeefs",
        "futiliteit",
        "onnozele hals",
        "prop",
        "gal",
        "galg",
        "gokken",
        "speler",
        "het gokken",
        "bende",
        "gevangenis",
        "kloof",
        "vuilnis",
        "opzichtig",
        "garnering",
        "Jaap",
        "hijgend",
        "NO TRANSLATION",
        "mager",
        "gent",
        "geriatrisch",
        "afgrijselijk",
        "getto",
        "spookachtig",
        "koeterwaals",
        "ijzig",
        "schittering",
        "schreeuwend",
        "welbespraakt",
        "somberheid",
        "somber",
        "sip",
        "overvoeren",
        "gulzigheid",
        "kabouter",
        "aardmannetje",
        "goddeloos",
        "gonorroe",
        "goo",
        "geronnen bloed",
        "kloof",
        "gorilla",
        "bloederig",
        "roddel",
        "guts",
        "jicht",
        "regering",
        "grijpen",
        "inhalig",
        "rooster",
        "geraspte",
        "rooster",
        "graf",
        "hebzucht",
        "gulzig",
        "granaat",
        "verdriet",
        "grief",
        "treuren",
        "smartelijk",
        "grimmig",
        "vuil",
        "vuil",
        "slijpen",
        "griezelig",
        "grizzly",
        "kreunen",
        "NO TRANSLATION",
        "bruto",
        "grotesk",
        "geaard",
        "ongegrond",
        "grommen",
        "grommen",
        "wrok",
        "onwillig",
        "ijzingwekkend",
        "nors",
        "mopperen",
        "knorrig",
        "guerilla",
        "bedrog",
        "guillotine",
        "schuld",
        "schuldig",
        "mom",
        "meeuw",
        "lichtgelovig",
        "geweer",
        "gutsen",
        "guzzling",
        "zigeuner",
        "heks",
        "verwilderd",
        "harig",
        "halverwege",
        "hallucinatie",
        "halster",
        "kreupel",
        "hinderen",
        "verminken",
        "handicap",
        "opknoping",
        "beul",
        "kwellen",
        "voorbode",
        "gehard",
        "hardheid",
        "ontbering",
        "hoer",
        "kwaad",
        "schadelijk",
        "hartverscheurend",
        "harry",
        "hardheid",
        "hachee",
        "hasj",
        "haastig",
        "een hekel hebben aan",
        "hatelijk",
        "haten",
        "haat",
        "hooghartig",
        "spoken",
        "spookt",
        "verwoesting",
        "risico",
        "gevaarlijk",
        "nevel",
        "hoofdpijn",
        "koppig",
        "gehoor",
        "gerucht",
        "lijkwagen",
        "hartzeer",
        "maagzuur",
        "harteloos",
        "heidenen",
        "hard",
        "hiel-",
        "verhogen",
        "gruwelijk",
        "hel",
        "hels",
        "hulpeloos",
        "hulpeloosheid",
        "bloeding",
        "aambeien",
        "ketterij",
        "ketter",
        "hermafrodiet",
        "heroïne",
        "herpes",
        "herpesvirus",
        "aarzeling",
        "verborgen",
        "afschuwelijk",
        "belemmerend",
        "hinder",
        "hippie",
        "fluiten",
        "sissend",
        "raken",
        "tot nu toe",
        "bijenkorf",
        "hees",
        "grijs",
        "hoax",
        "landloper",
        "varken",
        "hol",
        "brandoffer",
        "dakloos",
        "heimwee",
        "moorddadig",
        "moordenaar",
        "homoseksualiteit",
        "kap",
        "verslaafd",
        "toeteren",
        "hopeloos",
        "hopeloosheid",
        "horde",
        "verschrikkelijk",
        "verschrikkelijk",
        "afschuwelijk",
        "gruwelijk",
        "geschokt",
        "gruwelijke",
        "verschrikking",
        "verschrikkingen",
        "gijzelaar",
        "vijandig",
        "vijandelijkheden",
        "vijandigheid",
        "gehuil",
        "tieren",
        "humbug",
        "vernederen",
        "vernederend",
        "vernedering",
        "ingeving",
        "hongerig",
        "jager",
        "jacht-",
        "orkaan",
        "gehaast",
        "pijn doen",
        "schadelijk",
        "kwetsen",
        "energinemens",
        "hydra",
        "waterhoofd",
        "hype",
        "hyperbool",
        "huichelarij",
        "huichelaar",
        "schijnheilig",
        "hysterie",
        "hysterisch",
        "idiotie",
        "idioot",
        "idioot",
        "leegloper",
        "afgoderij",
        "onwetendheid",
        "onwetend",
        "negeren",
        "ziek",
        "onwettig",
        "onwettigheid",
        "onleesbaar",
        "onwettig",
        "ongeoorloofd",
        "analfabeet",
        "ziekte",
        "onlogisch",
        "illusie",
        "geïmiteerd",
        "imitatie",
        "onvolwassen",
        "onrijpheid",
        "onzedelijk",
        "onzedelijkheid",
        "aantasten",
        "verslechtering",
        "onbegaanbaar",
        "ongeduld",
        "ongeduldig",
        "beschuldigen",
        "beschuldiging",
        "belemmeren",
        "onvolmaaktheid",
        "onvolkomen",
        "verpersoonlijken",
        "verpersoonlijking",
        "onverzoenlijk",
        "betrekken",
        "onbeleefd",
        "oplegging",
        "onmogelijk",
        "impotentie",
        "onmachtig",
        "confisqueren",
        "onuitvoerbaar",
        "opsluiten",
        "gevangen",
        "gevangenisstraf",
        "ongepastheid",
        "onvoorzichtig",
        "onzuiver",
        "onzuiverheid",
        "aantijging",
        "onvermogen",
        "ontoegankelijk",
        "onnauwkeurig",
        "werkeloosheid",
        "inactiviteit",
        "ontoereikendheid",
        "ontoereikend",
        "ontoelaatbaar",
        "zinloos",
        "niet van toepassing",
        "ongepast",
        "onoplettendheid",
        "onhoorbaar",
        "onberekenbaar",
        "onbekwaamheid",
        "opsluiting",
        "in geval dat",
        "brandstichter",
        "wierook",
        "onophoudelijk",
        "incest",
        "bloedschendig",
        "verbranding",
        "aansporen",
        "guur",
        "onsamenhangend",
        "onverenigbaar",
        "onbekwaamheid",
        "onbekwaam",
        "onvolledigheid",
        "onbegrijpelijk",
        "ongerijmd",
        "inconsequent",
        "onbezonnen",
        "tegenstrijdigheid",
        "lastig",
        "niet correct",
        "ongelovig",
        "beschuldiging",
        "incubus",
        "oplopen",
        "ongeneeslijke",
        "inval",
        "onfatsoenlijk",
        "besluiteloosheid",
        "besluiteloos",
        "onverdedigbaar",
        "schadeloosstellen",
        "leerkontrakt",
        "onbepaald",
        "aanklagen",
        "aanklacht",
        "onverschilligheid",
        "behoeftig",
        "verontwaardigd",
        "verontwaardiging",
        "onduidelijk",
        "indoctrinatie",
        "indolent",
        "niet effectief",
        "vruchteloos",
        "ondoeltreffendheid",
        "inefficiënt",
        "onzinnig",
        "onzinnigheid",
        "ongelijkheid",
        "onbillijk",
        "inerte",
        "onvergeeflijk",
        "NO TRANSLATION",
        "onervaren",
        "onverklaarbaar",
        "berucht",
        "schanddaad",
        "kindermoord",
        "kinderlijk",
        "infarct",
        "infecteren",
        "infectie",
        "besmettelijk",
        "inferieur",
        "minderwaardigheid",
        "hel",
        "onvruchtbaarheid",
        "plaag",
        "ongelovige",
        "ontrouw",
        "zwak",
        "zwakte",
        "ontsteking",
        "opgeblazen",
        "inflatie",
        "toebrengen",
        "toebrengen",
        "influenza",
        "aangever",
        "inbreuk",
        "zeldzaam",
        "inbreuk",
        "verhinderen",
        "onherbergzaam",
        "onmenselijk",
        "onmenselijkheid",
        "vijandig",
        "ongerechtigheid",
        "bevel",
        "verwonden",
        "gewond",
        "schadelijk",
        "letsel",
        "onrecht",
        "bewoner",
        "buiten werking",
        "krankzinnig",
        "krankzinnigheid",
        "onzeker",
        "onzekerheid",
        "verraderlijk",
        "onbeduidendheid",
        "onbelangrijk",
        "smakeloos",
        "onbeschaamd",
        "insolventie",
        "insolvent",
        "onbestendigheid",
        "aansporen",
        "instigatie",
        "ontoereikendheid",
        "niet voldoende",
        "onvoldoende",
        "belediging",
        "beledigend",
        "opstandeling",
        "onoverkomelijk",
        "opstand",
        "onder",
        "verbod",
        "inmenging",
        "teraardebestelling",
        "onderbreken",
        "onderbroken",
        "zonder testament",
        "intimideren",
        "intimidatie",
        "ondraaglijk",
        "onverdraagzaamheid",
        "onverdraagzaam",
        "dronken",
        "onhandelbaar",
        "intrigeren",
        "indringer",
        "indringing",
        "opdringerig",
        "binnenvallen",
        "binnendringer",
        "ontzenuwen",
        "ongeldigverklaring",
        "invaliditeit",
        "invasie",
        "onwillekeurig",
        "machtsverheffing",
        "verbolgen",
        "NO TRANSLATION",
        "boeien",
        "irrationeel",
        "onredelijkheid",
        "onverzoenlijk",
        "onregelmatig",
        "onregelmatigheid",
        "irrelevant",
        "onherstelbaar",
        "onverantwoordelijk",
        "oneerbiedig",
        "onherroepelijk",
        "prikkelbaarheid",
        "prikkelbaar",
        "irritant",
        "ergernis",
        "geïsoleerd",
        "isolatie",
        "wauwelen",
        "gevangenis",
        "jargon",
        "woordenstrijd",
        "geelzucht",
        "jaloers",
        "jaloezie",
        "in gevaar brengen",
        "gevaar",
        "John",
        "grap",
        "NO TRANSLATION",
        "mengelmoes",
        "rommel",
        "junta",
        "jeugdig",
        "kern",
        "trap",
        "ontvoeren",
        "doden",
        "doden",
        "vlieger",
        "doodsklok",
        "geknoopt",
        "moeizaam",
        "moeizaam",
        "labyrint",
        "gebrek",
        "ontbrekend",
        "dof",
        "beladen",
        "vertraging",
        "achterblijvende",
        "hol",
        "weeklacht",
        "aardverschuiving",
        "loom",
        "wegkwijnen",
        "kwijnend",
        "verloop",
        "diefstal",
        "zweepslag",
        "laat",
        "laatheid",
        "latent",
        "latrines",
        "lachwekkend",
        "lava",
        "wetteloosheid",
        "rechtszaak",
        "advocaat",
        "laks",
        "laxeermiddel",
        "lui",
        "lek",
        "lekkage",
        "lek",
        "het verlof",
        "bloedzuiger",
        "bloedzuigers",
        "NO TRANSLATION",
        "citroen",
        "lepra",
        "lesbienne",
        "verminderen",
        "minder",
        "dodelijk",
        "loomheid",
        "leukemie",
        "heffing",
        "ontuchtig",
        "liaison",
        "leugenaar",
        "smaad",
        "likken",
        "liggen",
        "levenloos",
        "beperkt",
        "slap",
        "pluis",
        "sterke drank",
        "lusteloos",
        "rechtzoekende",
        "procederen",
        "procesvoering",
        "betwistbaar",
        "nest",
        "razend",
        "brood",
        "leegloper",
        "NO TRANSLATION",
        "verafschuwen",
        "walging",
        "walgelijk",
        "lobbyist",
        "NO TRANSLATION",
        "sprinkhaan",
        "verheven",
        "eenzaamheid",
        "eenzaam",
        "eenzaam",
        "toilet",
        "weefgetouw",
        "fuut",
        "gek",
        "buit",
        "verliezen",
        "verliezen",
        "verlies",
        "verloren",
        "loudness",
        "salon",
        "luis",
        "lager",
        "neerlaten",
        "laagste",
        "Lowlands",
        "nederig",
        "belachelijk",
        "voortsjokkend",
        "brok",
        "klonterige",
        "krankzinnigheid",
        "gek",
        "slingeren",
        "lokken",
        "luguber",
        "op de loer liggen",
        "loer",
        "weelderig",
        "lust",
        "wellustig",
        "aan het liegen",
        "lynchen",
        "foelie",
        "boos",
        "gek maken",
        "gek",
        "krankzinnigheid",
        "maffia",
        "made",
        "noodoplossing",
        "ziekte",
        "malaise",
        "malaria-",
        "kwaadwillig",
        "misdadiger",
        "misvorming",
        "kwaadaardigheid",
        "kwaadaardig",
        "kwaadaardig",
        "kwaadaardigheid",
        "kwaadaardig",
        "wangedrag",
        "mandamus",
        "NO TRANSLATION",
        "mangel",
        "manie",
        "maniac",
        "waanzinnig",
        "manipuleren",
        "manipulatie",
        "doodslag",
        "mest",
        "bederven",
        "marge",
        "kastanjebruin",
        "martingaal",
        "martelaar",
        "marteldood",
        "masochisme",
        "bloedbad",
        "materialisme",
        "materialist",
        "meanderende",
        "zinloos",
        "mazelen",
        "zich bemoeien",
        "middelmatig",
        "middelmatigheid",
        "melancholicus",
        "weemoed",
        "melee",
        "melodrama",
        "kernsmelting",
        "bedreiging",
        "dreigend",
        "huurling",
        "huurling",
        "meedogenloos",
        "knoeien",
        "rommelig",
        "metastasis",
        "methanol",
        "meeldauw",
        "militie",
        "mimicry",
        "verkleinen",
        "minimum",
        "minderheid",
        "NO TRANSLATION",
        "wangedrag",
        "miskraam",
        "kattenkwaad",
        "ondeugend",
        "misvatting",
        "wangedrag",
        "ellendig",
        "jammerlijk",
        "ellende",
        "tegenslag",
        "misleid",
        "ongeluk",
        "verkeerde interpretatie",
        "misleiden",
        "misleidend",
        "wanbeheer",
        "wanverhouding",
        "verkeerde benaming",
        "misplaatsen",
        "misplaatst",
        "verkeerd voorstellen",
        "onjuiste voorstelling",
        "Misrepresented",
        "missend",
        "afwijking",
        "vergissing",
        "verkeerd",
        "minnares",
        "NO TRANSLATION",
        "verkeerd begrijpen",
        "misverstand",
        "misbruik",
        "mijt",
        "bende",
        "spot",
        "spotachtig",
        "molestering",
        "monochroom",
        "monopolist",
        "moesson",
        "monster",
        "wangedrocht",
        "humeurig",
        "betwistbaar",
        "morbide",
        "ziektecijfers",
        "lijkenhuis",
        "stervende",
        "achterlijk persoon",
        "debiele",
        "hapje",
        "sterfelijk",
        "sterfte",
        "versterving",
        "lijkenhuis",
        "mug",
        "rouwen",
        "treurig",
        "rouw",
        "mest",
        "modder",
        "warboel",
        "warrige",
        "modderig",
        "mof",
        "muildier",
        "mamma",
        "mompelen",
        "de bof",
        "moord",
        "moordenaar",
        "moorddadig",
        "duister",
        "NO TRANSLATION",
        "muf",
        "mutant",
        "verminkt",
        "verminking",
        "muiterij",
        "NO TRANSLATION",
        "snuit",
        "bijziendheid",
        "betrappen",
        "nadir",
        "NO TRANSLATION",
        "naief",
        "naamloos",
        "luier",
        "verdovend",
        "smerig",
        "stout",
        "misselijkheid",
        "misselijk",
        "NO TRANSLATION",
        "nodig",
        "behoeftig",
        "schandelijk",
        "negatie",
        "negatief",
        "verwaarlozing",
        "verwaarloosd",
        "verwaarlozen",
        "nalatigheid",
        "nalatig",
        "NO TRANSLATION",
        "neger",
        "nepotisme",
        "nerveus",
        "onderwereld",
        "brandnetel",
        "zenuwpijn",
        "neurose",
        "neurotisch",
        "nicotine",
        "neger",
        "nachtmerrie",
        "nihilisme",
        "lawaai",
        "luidruchtig",
        "NO TRANSLATION",
        "onzin",
        "onzinnig",
        "strop",
        "nietigheid",
        "schadelijk",
        "overlast",
        "NO TRANSLATION",
        "vernietigen",
        "verdoven",
        "doof gevoel",
        "NO TRANSLATION",
        "pummel",
        "zwaarlijvig",
        "zwaarlijvigheid",
        "obi",
        "herdenkingsdienst",
        "doodsbrief",
        "bezwaar",
        "verwerpelijk",
        "verplichten",
        "schuldenaar",
        "uitwissen",
        "uitgewist",
        "afstempeling",
        "vergetelheid",
        "onaangenaam",
        "obsceen",
        "obsceniteit",
        "duisternis",
        "hindernis",
        "koppig",
        "belemmeren",
        "obstructie",
        "belemmerend",
        "stomp",
        "occult",
        "vreemdheid",
        "verfoeilijk",
        "geur",
        "beledigen",
        "beledigd",
        "overtreder",
        "overtreding",
        "aanvallend",
        "onvoorbereid",
        "volle zee",
        "boeman",
        "reuk-",
        "oligarchie",
        "voorteken",
        "onheilspellend",
        "weglaten",
        "bezwaarlijk",
        "bewijslast",
        "slijk",
        "ondoorzichtig",
        "opera-",
        "opiaat",
        "eigenzinnig",
        "opium",
        "tegenstander",
        "zich verzetten tegen",
        "gekant tegen",
        "oppositie",
        "onderdrukken",
        "onderdrukking",
        "onderdrukkend",
        "onderdrukker",
        "orc",
        "beproeving",
        "geschut",
        "wees-",
        "ogenschijnlijk",
        "verdrijven",
        "verschoppeling",
        "geschreeuw",
        "bijgebouw",
        "vreemd",
        "balling",
        "verontwaardiging",
        "ovatie",
        "aanmatigend",
        "overbelasten",
        "bewolking",
        "overdrijven",
        "overdosis",
        "achterstallig",
        "overschat",
        "overloop",
        "overwoekerd",
        "overbelasten",
        "te veel betaald",
        "overweldigen",
        "overweldigend",
        "overpriced",
        "toezicht",
        "omverwerping",
        "omvallen",
        "overweldigen",
        "overweldigd",
        "onder meer omdat",
        "oxydatie",
        "pijn",
        "gepijnigd",
        "pijnlijk",
        "pijnlijk",
        "pijnen",
        "verlamming",
        "pandemisch",
        "NO TRANSLATION",
        "paniek",
        "verlamming",
        "verlamd",
        "paranoia",
        "parasiet",
        "NO TRANSLATION",
        "papegaai",
        "karig",
        "partijdig",
        "NO TRANSLATION",
        "passief",
        "passiviteit",
        "lap",
        "zielig",
        "neerbuigend",
        "NO TRANSLATION",
        "gebrek",
        "armlastige",
        "pion",
        "terugverdientijd",
        "betaling",
        "eigenaardigheden",
        "voetganger",
        "straf-",
        "boete",
        "doordringen",
        "strafinrichting",
        "verderf",
        "gevaar",
        "gevaarlijk",
        "vergaan",
        "beperkt houdbaar",
        "omgekomen",
        "vergankelijk",
        "meineed",
        "verderfelijk",
        "dader",
        "vereeuwiging",
        "verward",
        "verwarring",
        "vervolgen",
        "vervolging",
        "verstoring",
        "pertussis",
        "pervers",
        "verdraaiing",
        "verdraaien",
        "pervers",
        "pessimisme",
        "pessimist",
        "plaag",
        "pestilentie",
        "huisdier",
        "kleinzielig",
        "spook",
        "slijm",
        "onecht",
        "piket",
        "picket",
        "augurk",
        "varken",
        "duif",
        "aambeien",
        "plundering",
        "souteneur",
        "puistje",
        "pijnboom",
        "rondsel",
        "wrok",
        "zeeroof",
        "piraat",
        "pistool",
        "valkuil",
        "plagiaat",
        "pest",
        "eiser",
        "plated",
        "speler",
        "pleiten",
        "toestand",
        "gezwoeg",
        "schietlood",
        "plunderen",
        "duiken",
        "longontsteking",
        "stroperij",
        "stomp",
        "vergiftigen",
        "vergiftigd",
        "vergiftiging",
        "giftig",
        "por",
        "polemiek",
        "polio",
        "verontreinigen",
        "verontreiniging",
        "veelwijverij",
        "praal",
        "hoogdravend",
        "zwaarwichtig",
        "slecht",
        "knal",
        "stekelvarken",
        "porno",
        "porno",
        "pornografisch",
        "pornografie",
        "pose",
        "bezeten",
        "bezit",
        "nagelaten",
        "uitstel",
        "pond",
        "armoede",
        "machteloos",
        "streek",
        "precair",
        "politiedistrict",
        "roofzuchtig",
        "netelige positie",
        "zwangerschap",
        "vooroordeel",
        "bevooroordeeld",
        "schadelijk",
        "met voorbedachten rade",
        "druk",
        "aanmatigend",
        "doen alsof",
        "deed alsof",
        "zogenaamd",
        "schijn",
        "pretenties",
        "preventieve",
        "prooi",
        "prik",
        "stekelig",
        "gevangenis",
        "gevangene",
        "privaat",
        "probleem",
        "talmen",
        "uitstelgedrag",
        "ontheiligen",
        "heiligschennis",
        "overvloed",
        "verboden",
        "verbod",
        "verlengen",
        "gemengd",
        "propaganda",
        "vervolgen",
        "vervolging",
        "prostitueren",
        "prostitutie",
        "provocatie",
        "provoceren",
        "wrikken",
        "nieuwsgierige",
        "psychose",
        "journalist",
        "gezwollen",
        "stempel",
        "scherp",
        "straffen",
        "gestraft",
        "te straffen",
        "straf",
        "straffend",
        "vagevuur",
        "zuivering",
        "pus",
        "kwakzalvers-",
        "moeras",
        "kwartel",
        "verlegenheid",
        "ruzie",
        "vernietigen",
        "onderdrukken",
        "twijfelachtig",
        "kwik",
        "ophouden",
        "trillen",
        "trillende",
        "quiz",
        "gespuis",
        "dol",
        "hondsdolheid",
        "rek",
        "racket",
        "bestraling",
        "radioactieve",
        "radon",
        "woede",
        "woedend",
        "lompen",
        "inval",
        "het spoor",
        "RAM",
        "onsamenhangend",
        "rampage",
        "ranzig",
        "losgeld",
        "verkrachting",
        "roofvogels",
        "deugniet",
        "uitslag",
        "Rat",
        "beoordeling",
        "schor",
        "uitgehongerd",
        "ijlend",
        "reactionair",
        "achterkant",
        "rebel",
        "berisping",
        "weerleggen",
        "weerspannige",
        "recessie",
        "recidive",
        "roekeloos",
        "roekeloosheid",
        "overtollig",
        "reflux",
        "vuurvast",
        "weigering",
        "weigeren",
        "geweigerd",
        "regressie",
        "regressie",
        "betreuren",
        "betreurenswaardig",
        "betreurde",
        "betreurend",
        "regelgevende",
        "beteugelen",
        "afwijzen",
        "verworpen",
        "afwijzing",
        "verwerpt",
        "instorting",
        "verbanning",
        "afstaan",
        "onwillig",
        "terugzending",
        "remedial",
        "nalatig",
        "spijt",
        "verwijdering",
        "verwijderen",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "afvallige",
        "afstand doen van",
        "verzaking",
        "NO TRANSLATION",
        "afstotend",
        "afstotende",
        "onderdrukken",
        "repressie",
        "berisping",
        "herdruk",
        "represaille",
        "verwijt",
        "republiek",
        "verstoting",
        "afstoting",
        "herroepen",
        "ontbinding",
        "aanstoot nemen",
        "haatdragend",
        "wrok",
        "ontslag nemen",
        "ontslag",
        "ontslag genomen",
        "weerstand bieden",
        "weerstand",
        "resistant",
        "weerstaan",
        "in bedwang houden",
        "beperken",
        "beperking",
        "beperkend",
        "vergelden",
        "wraak",
        "vergeldings-",
        "vertragen",
        "vertraging",
        "terughoudend",
        "retort",
        "terugtrekken",
        "intrekking",
        "bezuiniging",
        "vergelding",
        "achteruitgang",
        "wraak",
        "omkering",
        "herroeping",
        "intrekken",
        "opstand",
        "weerzinwekkend",
        "revolver",
        "afkeer",
        "reumatiek",
        "gammel",
        "doorzeefd",
        "belachelijk maken",
        "belachelijk",
        "schering en inslag",
        "geweer-",
        "scheur",
        "stijf",
        "stijfheid",
        "strengheid",
        "streng",
        "beltoon",
        "herrie",
        "oproerig",
        "risico",
        "riskant",
        "rivaliteit",
        "beroven",
        "rover",
        "diefstal",
        "schurk",
        "roek",
        "rot",
        "rottende",
        "ruwheid",
        "NO TRANSLATION",
        "rij",
        "herriemaker",
        "onzin",
        "puin",
        "rue",
        "rimpeling",
        "ruig",
        "ruïneren",
        "geruïneerd",
        "verderfelijk",
        "gerucht",
        "Weglopen",
        "scheuren",
        "NO TRANSLATION",
        "Roest",
        "roestig",
        "meedogenloos",
        "NO TRANSLATION",
        "sabotage",
        "offers",
        "droevig",
        "droefheid",
        "doorzakken",
        "sap",
        "sarcasme",
        "sarcoma",
        "sardonisch",
        "satanische",
        "verzadigd",
        "wilde",
        "wreedheid",
        "schurft",
        "steiger",
        "scalpel",
        "geschubd",
        "schandaal",
        "schandalig",
        "schaars",
        "zondebok",
        "litteken",
        "schaars",
        "nauwelijks",
        "schaarste",
        "laten schrikken",
        "straatveger",
        "schema",
        "schisma",
        "schizofrenie",
        "ischias",
        "spotten",
        "schelden",
        "uitbrander",
        "gloeiend",
        "hoon",
        "schorpioen",
        "Scotch",
        "schurk",
        "geselen",
        "klauteren",
        "scrapie",
        "schreeuw",
        "schreeuwen",
        "krijsen",
        "geschroefd",
        "scrimmage",
        "schrobben",
        "onderzoeken",
        "nauwkeurig onderzoek",
        "uitschot",
        "verdroogd",
        "afscheiding",
        "afgezonderd",
        "NO TRANSLATION",
        "afscheiding",
        "geheimzinnig",
        "sektarisch",
        "opruiing",
        "verleiden",
        "verleiding",
        "scheiden",
        "gesegregeerde",
        "beslag leggen op",
        "egoïstisch",
        "egoïsme",
        "seniel",
        "zinloos",
        "zin",
        "separatist",
        "bloedvergiftiging",
        "septisch",
        "beslaglegging",
        "sereen",
        "slang",
        "knecht",
        "dienen",
        "slaafs-",
        "dienstbaarheid",
        "tegenslag",
        "verbreken",
        "rioolwater",
        "riolering",
        "haveloos",
        "keet",
        "sluiting",
        "schaduwrijk",
        "schudden",
        "wankel",
        "schijn",
        "janboel",
        "schaamte",
        "schandelijk",
        "schaamteloos",
        "Sjanghai",
        "haai",
        "breken",
        "verbrijzeld",
        "schuur",
        "schelp",
        "opgeschort",
        "schipbreuk",
        "stront",
        "rilling",
        "schok",
        "kitsch",
        "schieten",
        "het schieten",
        "winkeldiefstal",
        "tekort",
        "Tekortkoming",
        "schot",
        "duw",
        "opzichtig",
        "schreeuw",
        "schel",
        "krimpen",
        "gekrompen",
        "huiveren",
        "vlieden",
        "ziek",
        "misselijk",
        "ziekelijk",
        "ziekte",
        "dwaas",
        "NO TRANSLATION",
        "zondig",
        "sinister",
        "zondaar",
        "zondigen",
        "sirene",
        "mietje",
        "sceptisch",
        "oppervlakkig",
        "scheef",
        "slippen",
        "overspringen",
        "schermutseling",
        "speling",
        "slak",
        "dichtslaan",
        "laster",
        "lasterlijk",
        "klap",
        "slachten",
        "slachthuis",
        "slachten",
        "slaaf",
        "slavernij",
        "doden",
        "moordenaar",
        "ijzel",
        "slijmerig",
        "sluipen",
        "uitglijden",
        "NO TRANSLATION",
        "slordig",
        "luiaard",
        "slungelen",
        "moeras",
        "traagheid",
        "modder",
        "naaktslak",
        "traag",
        "achterbuurt",
        "malaise",
        "smet",
        "slush",
        "slet",
        "sluw",
        "slaan",
        "klein",
        "intrappen",
        "vernield",
        "oppervlakkige kennis",
        "geur",
        "ruikend",
        "meesmuilen",
        "slaan",
        "roker",
        "smoren",
        "vlekken",
        "zelfgenoegzaam",
        "smokkelen",
        "smokkelaar",
        "smokkelen",
        "roetvlek",
        "moeilijkheid",
        "haken en ogen",
        "slang",
        "strik",
        "grauwen",
        "snauwen",
        "sluipen",
        "sluipen",
        "grijns",
        "niezen",
        "fals",
        "snob",
        "weken",
        "NO TRANSLATION",
        "socialist",
        "bodem",
        "vuil",
        "somatische",
        "somber",
        "roet",
        "tovenarij",
        "gemeen",
        "zeer",
        "sorely",
        "pijnlijkheid",
        "leed",
        "treurig",
        "NO TRANSLATION",
        "zielloos",
        "zielsverwant",
        "zuur",
        "afranselen",
        "spasme",
        "slobkous",
        "speer",
        "vlek",
        "spook",
        "spectraal",
        "speculatie",
        "doorgebracht",
        "oude vrijster",
        "wrok",
        "hatelijk",
        "splinter",
        "spleet",
        "splitsing",
        "Bederven",
        "spoiler",
        "spaak",
        "spons",
        "spook",
        "verstuiking",
        "Spree",
        "sprite",
        "onecht",
        "bui",
        "kraker",
        "preuts",
        "squelch",
        "kronkelen",
        "steken",
        "onthutsend",
        "stilstaand",
        "vlek",
        "muf",
        "stengel",
        "impasse",
        "blijf staan",
        "staren",
        "strak",
        "doen schrikken",
        "uithongering",
        "uitgehongerd",
        "hongerig",
        "stationair",
        "duig",
        "stelen",
        "diefstal",
        "heimelijk",
        "stereotiep",
        "stereotiep",
        "steriel",
        "steriliteit",
        "achtersteven",
        "stijf",
        "stijfheid",
        "verstikken",
        "verstikt",
        "stigma",
        "doodgeboren",
        "steek",
        "prikkelend",
        "gierig",
        "stinken",
        "stinkend",
        "stint",
        "aandelen",
        "gestolen",
        "steen",
        "gestenigd",
        "ontlasting",
        "stopzetting",
        "storm",
        "stormachtig",
        "gespannen",
        "zeeëngte",
        "gestrand",
        "vreemdeling",
        "wurgen",
        "verdwaald",
        "spanning",
        "strijd",
        "staking",
        "strip",
        "streep",
        "gestript",
        "beroerte",
        "worstelen",
        "stut",
        "benauwd",
        "struikelen",
        "verbijsterd",
        "onvolgroeide",
        "dom",
        "domheid",
        "verdoving",
        "strontje",
        "onderwerpen",
        "onderwerpen",
        "onderworpen",
        "onderwerping",
        "onderwerping",
        "ondergeschikt",
        "dagvaarden",
        "verzakking",
        "subsidie",
        "bestaan",
        "aftrekken",
        "omverwerping",
        "subversief",
        "ondermijnen",
        "bezwijken",
        "zuigen",
        "zuignap",
        "vervolgen",
        "lijden",
        "lijder",
        "lijden",
        "verstikkende",
        "verstikking",
        "suïcidaal",
        "zelfmoord",
        "nors",
        "dagvaarding",
        "gezonken",
        "oppervlakkig",
        "overbodig",
        "bijgelovig",
        "onderdrukken",
        "onderdrukking",
        "toeslag",
        "nors",
        "overgave",
        "overgave",
        "vatbaar",
        "verdachte",
        "suspensie",
        "achterdocht",
        "verdacht",
        "zwabber",
        "moeras",
        "moerassig",
        "swastika",
        "zwelling",
        "slok",
        "zwijn",
        "gezwollen",
        "symptoom",
        "syncope",
        "taboe",
        "smet",
        "NO TRANSLATION",
        "verwarde",
        "traagheid",
        "traag",
        "tarief",
        "aanslag",
        "teerachtig",
        "smaakloos",
        "beschimpen",
        "belasting",
        "plagen",
        "plagen",
        "vervelend",
        "NO TRANSLATION",
        "storm",
        "verleiding",
        "woning",
        "terminal",
        "beëindiging",
        "termiet",
        "verschrikkelijk",
        "terreur",
        "terrorisme",
        "terrorist",
        "terroriseren",
        "tetanus",
        "ketting",
        "diefstal",
        "theïsme",
        "theocratisch",
        "dief",
        "dorstig",
        "doorn",
        "netelig",
        "gedachteloos",
        "slaan",
        "bedreiging",
        "dreigen",
        "dreigend",
        "dorsen",
        "kloppen",
        "smoorklep",
        "gangster",
        "stomp",
        "donderende",
        "dwarsbomen",
        "tiff",
        "timide",
        "schroom",
        "aangeschoten",
        "tirade",
        "moe",
        "vermoeidheid",
        "vermoeiend",
        "mees",
        "pad",
        "tabak-",
        "toilet",
        "strikken",
        "tolereren",
        "kiespijn",
        "kwelling",
        "gescheurd",
        "torpedo-",
        "verzengend",
        "onrechtmatige daad",
        "onrechtmatig",
        "martelen",
        "aangeraakt",
        "gevoelig",
        "taai",
        "giftig",
        "toxine",
        "tragedie",
        "tragisch",
        "verrader",
        "landloper",
        "trance",
        "overtreding",
        "tooi",
        "traps",
        "uitschot",
        "prullerig",
        "traumatisch",
        "NO TRANSLATION",
        "travestie",
        "verraderlijk",
        "verraad",
        "verraad",
        "bevend",
        "tremor",
        "schroom",
        "overtreding",
        "beproeving",
        "tribunaal",
        "truc",
        "bedriegerij",
        "kleinigheid",
        "struikelen",
        "trol",
        "lastig",
        "trompet",
        "tuimelen",
        "tumor",
        "tumor",
        "tumult",
        "onstuimig",
        "onstuimigheid",
        "wild",
        "beroering",
        "zenuwtrekking",
        "tyfoon",
        "tiranniek",
        "tirannie",
        "tiran",
        "lelijkheid",
        "lelijk",
        "zweer",
        "verborgen",
        "ultimatum",
        "niet in staat",
        "niet aanvaardbaar",
        "onverklaarbaar",
        "goedgekeurde",
        "niet verbonden",
        "onbereikbaar",
        "onaantrekkelijk",
        "onbevoegd",
        "onvermijdelijk",
        "onbewust",
        "ondraaglijk",
        "ongeloof",
        "ongelooflijk",
        "ongeboren",
        "geheimzinnig",
        "onverschillig",
        "onzeker",
        "onveranderlijk",
        "onrein",
        "ongemakkelijk",
        "onredelijk",
        "bewusteloos",
        "ongrondwettig",
        "niet te beheersen",
        "ongecontroleerde",
        "onbeslist",
        "ondermijnd",
        "slecht betaald",
        "ondermaatse",
        "ongewenst",
        "ongewenste",
        "ongedaan maken",
        "onbehaaglijkheid",
        "ongemakkelijk",
        "onopgevoed",
        "werkloos",
        "ongelijk",
        "ongelijk",
        "onverklaard",
        "oneerlijk",
        "oneerlijkheid",
        "ontrouw",
        "ongunstig",
        "onafgewerkt",
        "onverzoenlijk",
        "ongelukkige",
        "onvriendelijk",
        "niet vervuld",
        "gestoffeerd",
        "goddeloos",
        "ondankbaar",
        "ongelukkigheid",
        "ongelukkig",
        "ongezond",
        "onheilig",
        "onbelangrijk",
        "niet onder de indruk",
        "onverbeterd",
        "onwetend",
        "oningewijd",
        "onbezield",
        "onbegrijpelijk",
        "onopzettelijk",
        "niet geïnteresseerd",
        "oninteressant",
        "onrechtvaardig",
        "niet te rechtvaardigen",
        "ongerechtvaardigd",
        "onaardig",
        "onbekend",
        "onwettig",
        "zonder vergunning",
        "ongelukkig",
        "onhandelbaar",
        "onnatuurlijk",
        "officieus",
        "onbetaald",
        "onplezierig",
        "onpopulair",
        "onvoorspelbaar",
        "onvoorbereid",
        "onproductieve",
        "onvoordelig",
        "onbeschermd",
        "onuitgegeven",
        "onbetrouwbaar",
        "onbeantwoord",
        "onhandelbaar",
        "onveilig",
        "onbevredigend",
        "niet tevreden",
        "onverkwikkelijk",
        "gewetenloos",
        "onbestendig",
        "lelijk",
        "onbedorven",
        "onuitsprekelijk",
        "wankel",
        "mislukt",
        "ongeschikt",
        "niet bezongen",
        "niet gesteund",
        "onhoudbaar",
        "niet sympathiek",
        "ongetemd",
        "onhoudbaar",
        "ondenkbaar",
        "slordig",
        "ontijdig",
        "untitled",
        "onnoemelijk",
        "ongunstig",
        "ongetraind",
        "onwaar",
        "onbetrouwbaar",
        "ongerechtvaardigd",
        "ongewassen",
        "onwelkom",
        "onwel",
        "onwil",
        "onverstandig",
        "onbewust",
        "onwaardig",
        "onverzettelijk",
        "omwenteling",
        "opstand",
        "lawaai",
        "boos",
        "egel",
        "dringend",
        "nutteloos",
        "usurperen",
        "toegeëigend",
        "woeker",
        "vacature",
        "nietsdoend",
        "vaag",
        "vaagheid",
        "vergeefs",
        "vampier",
        "verdwenen",
        "ijdelheid",
        "varicella",
        "spataderen",
        "vegetatief",
        "heftig",
        "vendetta",
        "wraak",
        "wraakgierig",
        "venijn",
        "giftig",
        "breedsprakigheid",
        "berm",
        "ongedierte",
        "versus",
        "duizeligheid",
        "veto",
        "ondeugd",
        "verdorven",
        "slachtoffer",
        "slachtoffer",
        "schurk",
        "schurkachtig",
        "wraakzuchtig",
        "schending",
        "geweld",
        "gewelddadig",
        "met geweld",
        "adder",
        "kwaadaardigheid",
        "virus",
        "visitatie",
        "feeks",
        "volatiliteit",
        "vulkaan",
        "braken",
        "voodoo",
        "grof",
        "vulgariteit",
        "kwetsbaarheid",
        "gier",
        "wafel",
        "weeklacht",
        "Wacht",
        "wentelen",
        "NO TRANSLATION",
        "afnemen",
        "willen",
        "oorlog",
        "bewaker",
        "aardewerk",
        "oorlogvoering",
        "oorlogszuchtig",
        "waarschuwen",
        "schering",
        "scheefgetrokken",
        "wrat",
        "verspilling",
        "verspild",
        "verkwistend",
        "verspilling",
        "waterig",
        "wankelen",
        "verzwakt",
        "zwak",
        "zwakheid",
        "slijtage",
        "vermoeid",
        "vermoeidheid",
        "vermoeid",
        "onkruid",
        "huilen",
        "vreemd",
        "weirdo",
        "NO TRANSLATION",
        "deern",
        "meppen",
        "gril",
        "zeuren",
        "zweep",
        "wervelwind",
        "whisky",
        "hoer",
        "slecht",
        "slechtheid",
        "wild",
        "wilde kat",
        "wildvuur",
        "opzettelijk",
        "watje",
        "wimpy",
        "huiveren",
        "heks",
        "hekserij",
        "terugtrekken",
        "verdorren",
        "verschrompeld",
        "wee",
        "jammerlijk",
        "jammerlijk",
        "tekst",
        "worm",
        "versleten",
        "bezorgd",
        "zorgen",
        "zorgwekkend",
        "erger",
        "verergering",
        "waardeloos",
        "wond",
        "geruzie",
        "toorn",
        "aanrichten",
        "wrak",
        "vernielde",
        "moersleutel",
        "het worstelen",
        "ellendeling",
        "ellendig",
        "fout",
        "overtreding",
        "onrechtmatig",
        "ten onrechte",
        "gesmeed",
        "scheef",
        "xenofobie",
        "geeuw",
        "geeuwen",
        "Gil",
        "geel",
        "gekef",
        "ritssluiting",
    ]
)

_ambivalent = set(
    [
        "overvloed",
        "gewapend",
        "balsem",
        "opscheppen",
        "onstuimig",
        "boekenworm",
        "reebok",
        "beroemdheid",
        "ingenomen",
        "omzeiling",
        "medeplichtigheid",
        "bekennen",
        "sluw",
        "afhankelijk",
        "verschillend",
        "heersen",
        "eindeloos",
        "afdwingen",
        "erotisch",
        "ontsnappen",
        "gevoel",
        "flirt",
        "wees gegroet",
        "hedonisme",
        "hoogst",
        "vernederen",
        "per direct",
        "onroerend",
        "inkomen",
        "infiltratie",
        "invloed",
        "intens",
        "eindeloos",
        "interventie",
        "kant",
        "liberaal",
        "heer",
        "moederlijk",
        "verloskundige",
        "moeder",
        "mok",
        "bekendheid",
        "almacht",
        "uitbarsting",
        "voortreffelijk",
        "parade",
        "parafrase",
        "petroleum",
        "aanbieding",
        "verkwister",
        "citaat",
        "rave",
        "regressieve",
        "weer op te rakelen",
        "stoffelijk overschot",
        "pensioen",
        "herleven",
        "revolutie",
        "vogelverschrikker",
        "afzondering",
        "sensueel",
        "schouwspel",
        "wervelkolom",
        "sterling",
        "sappig",
        "bijgeloof",
        "suprematie",
        "omringen",
        "synoniem",
        "verleidelijke",
        "tieners",
        "traktatie",
        "ongeslagen",
        "tomeloos",
        "niet verwacht",
        "ondenkbaar",
        "losmaken",
        "bergopwaarts",
        "stemmen",
        "gewicht",
        "smachtend verlangen",
    ]
)



"""
**********
Plutchik
**********

This package contains a data visualization tool for corpora annotated with emotions.
Given a JSON representation of the Plutchik's emotions (or dyads) in a text or in a group of texts, 
it draws the corresponding Plutchik's flower.

See Plutchik, Robert. "A general psychoevolutionary theory of emotion." Theories of emotion. Academic press, 1980. 3-33.

--------
repository available at https://www.github.com/alfonsosemeraro/pyplutchik
@author: Alfonso Semeraro <alfonso.semeraro@gmail.com>

"""

import shapely.geometry as sg
import matplotlib.pyplot as plt

# import descartes
from math import cos, sin, radians
import numpy as np
import emoatlas.emotions as _emo_pluthick_
import emoatlas.dyads as _dyads_pluthick_
import warnings

warnings.simplefilter(action="ignore", category=FutureWarning)

__author__ = """Alfonso Semeraro (alfonso.semeraro@gmail.com)"""
__all__ = [
    "_rotate_point",
    "_polar_coordinates",
    "_neutral_central_circle",
    "_check_scores_kind",
    "draw_plutchik",
    "get_random_emotions",
    "get_random_dyads",
]

# def PolygonPatch(polygon, **kwargs):
#     """Constructs a matplotlib patch from a Polygon geometry

#     The `kwargs` are those supported by the matplotlib.patches.PathPatch class
#     constructor. Returns an instance of matplotlib.patches.PathPatch.

#     Example (using Shapely Point and a matplotlib axes)::

#         b = shapely.geometry.Point(0, 0).buffer(1.0)
#         patch = _PolygonPatch(b, fc='blue', ec='blue', alpha=0.5)
#         ax.add_patch(patch)

#     Emoatlas originally relied on the descartes package by Sean Gillies
#     (BSD license, https://pypi.org/project/descartes) for PolygonPatch, but
#     this dependency was removed in favor of the below matplotlib code.
#     """
#     from matplotlib.patches import PathPatch
#     from matplotlib.path import Path

#     path = Path.make_compound_path(
#         Path(np.asarray(polygon.exterior.coords)[:, :2]),
#         *[Path(np.asarray(ring.coords)[:, :2]) for ring in polygon.interiors],
#     )
#     return PathPatch(path, **kwargs)
#   This solution was mutuated from the GeoPandas library (https://geopandas.org/en/stable/).


def _rotate_point(point, angle):
    """
    Rotate a point counterclockwise by a given angle around a given origin.

    Required arguments:
    ----------
    *point*:
        A two-values tuple, (x, y), of the point to rotate

    *angle*:
        The angle the point is rotated. The angle should be given in radians.

    Returns:
    ----------
    *(qx, qy)*:
        A two-values tuple, the new coordinates of the rotated point.

    """
    ox, oy = 0, 0
    px, py = point
    angle = radians(angle)
    qx = ox + cos(angle) * (px - ox) - sin(angle) * (py - oy)
    qy = oy + sin(angle) * (px - ox) + cos(angle) * (py - oy)
    return (qx, qy)


def _polar_coordinates(
    ax,
    font,
    fontweight,
    fontsize,
    show_ticklabels,
    ticklabels_angle,
    ticklabels_size,
    rescale,
    all_ticks=True,
    offset=0.15,
):
    """
    Draws polar coordinates as a background.

    Required arguments:
    ----------
    *ax*:
        Axes to draw the coordinates.

    *font*:
        Font of text. Default is Montserrat.

    *fontweight*:
        Font weight of text. Default is light.

    *fontsize*:
        Font size of text. Default is 15.

    *show_ticklabels*:
        Boolean, wether to show tick labels under Joy petal. Default is False.

    *ticklabels_angle*:
        How much to rotate tick labels from y=0. Value should be given in radians. Default is 0.

    *ticklabels_size*:
        Size of tick labels. Default is 11.

    *all_ticks*:
        A boolean: wether underneath polar lines must be drawed or not.

    *offset*:
        Central neutral circle has radius = .15, and coordinates must start from there.

    Returns:
    ----------
    *ax*:
        The input Axes modified.

    """

    rg = range(0, 110, 20) if all_ticks else [100]

    # Lines
    for i in rg:
        c = plt.Circle(
            (0, 0), offset + i / 100, color="grey", alpha=0.3, fill=False, zorder=-20
        )
        ax.add_artist(c)

    if rescale:
        true_values = list(
            np.arange(rescale[0], rescale[1], (rescale[1] - rescale[0]) / 5)
        ) + [rescale[1]]
        true_values = true_values[-5:]

    else:
        true_values = np.arange(0.2, 1.2, 0.2)

    # Tick labels
    if show_ticklabels:
        for x, tv in zip(np.arange(0.2, 1.2, 0.2), true_values):
            a = "+{}".format(round(tv, 1)) if tv >= 0 else str(round(tv, 1))
            x, y = _rotate_point((0, x + offset), ticklabels_angle)  # -.12
            ax.annotate(
                text=a,
                xy=(x, y),
                fontfamily=font,
                size=ticklabels_size,
                fontweight=fontweight,
                zorder=8,
                rotation=ticklabels_angle,
            )
    return ax


def _neutral_central_circle(ax, r=0.15):
    """
    Draws central neutral circle (in grey).

    Required arguments:
    ----------
    *ax*:
        Axes to draw the coordinates.

    *r*:
        Radius of the circle. Default is .15.

    Returns:
    ----------
    *ax*:
        The input Axes modified.

    """
    c = sg.Point(0, 0).buffer(r)
    ax.add_patch(
        _emo_pluthick_.PolygonPatch(
            c, fc="white", ec=(0.5, 0.5, 0.5, 0.3), alpha=1, zorder=15
        )
    )

    return ax


def _check_scores_kind(tags):
    """
    Checks if the inputed scores are all of the same kind
    (emotions or primary dyads or secondary dyads or tertiary dyads or opposites).

    No mixed kinds are allowed.

    Required arguments:
    ----------

    *tags*:
        List of the tags provided as 'scores'.


    Returns:
    ----------

    A boolean, True if `scores` contains emotions, False if it contains dyads.

    """
    kinds = []
    for t in tags:
        try:
            kinds += [_emo_pluthick_.emo_params(t)[2]]
        except:
            kinds += [_dyads_pluthick_.dyad_params(t)[3]]

    unique_kinds = list(set(sorted(kinds)))

    if len(unique_kinds) > 1:
        unique_kinds_str = ", ".join([str(a) for a in unique_kinds])
        unique_kinds_str = unique_kinds_str.replace("0", "emotions")
        unique_kinds_str = unique_kinds_str.replace("1", "primary dyads")
        unique_kinds_str = unique_kinds_str.replace("2", "secondary dyads")
        unique_kinds_str = unique_kinds_str.replace("3", "tertiary dyads")
        unique_kinds_str = unique_kinds_str.replace("4", "opposite emotions")
        unique_kinds_str = " and".join(unique_kinds_str.rsplit(",", 1))

        error_str = "Bad input: can't draw {} altogether. Please input only one of them as 'scores'.".format(
            unique_kinds_str
        )
        raise Exception(error_str)

    else:

        kind = kinds[0]

        if kind == 0:
            return True
        else:
            return False


def _check_scores_list_kind(tags_list):
    """
    Checks if the inputed scores are all of the same kind
    (emotions or primary dyads or secondary dyads or tertiary dyads or opposites).

    No mixed kinds are allowed.

    Required arguments:
    ----------

    *tags_list*:
        List of the emotion/dyads scores, provided as 'scores_list'.


    Returns:
    ----------

    A boolean, True if `scores` contains emotions, False if it contains dyads.

    """
    kinds = []
    for tags in tags_list:
        print(tags)
        for t in tags.keys():
            try:
                kinds += [_emo_pluthick_.emo_params(t)[2]]
            except:
                kinds += [_dyads_pluthick_.dyad_params(t)[3]]

    unique_kinds = list(set(sorted(kinds)))

    if len(unique_kinds) > 1:
        unique_kinds_str = ", ".join([str(a) for a in unique_kinds])
        unique_kinds_str = unique_kinds_str.replace("0", "emotions")
        unique_kinds_str = unique_kinds_str.replace("1", "primary dyads")
        unique_kinds_str = unique_kinds_str.replace("2", "secondary dyads")
        unique_kinds_str = unique_kinds_str.replace("3", "tertiary dyads")
        unique_kinds_str = unique_kinds_str.replace("4", "opposite emotions")
        unique_kinds_str = " and".join(unique_kinds_str.rsplit(",", 1))

        error_str = "Bad input: can't draw {} altogether. Please input only one of them as 'scores'.".format(
            unique_kinds_str
        )
        raise Exception(error_str)

    else:

        kind = kinds[0]

        if kind == 0:
            return True
        else:
            return False


def _draw_rejection_region(ax, reject_range, rescale, offset=0.15):
    """
    Draws the rejection range.

    Required arguments:
    ----------

    *ax*:
        The matplotlib ax to draw the rejection range upon.

    *reject_range*:
        A 2-item tuple, defining a region of values to be considered uninteresting.

    *rescale*:
        Either False or a 2-item tuple, with minimum and maximum value of the printable area.

    *offset*:
        A scalar, the offset from the center of the circle, where petals begin. Default is 0.15.


    Returns:
    ----------

    The same Matplotlib axes modified.

    """

    mmin, mmax = reject_range

    mmin = (mmin - rescale[0]) / (rescale[1] - rescale[0]) + offset
    mmax = (mmax - rescale[0]) / (rescale[1] - rescale[0]) + offset

    c = sg.Point(0, 0).buffer(mmax)
    ax.add_patch(
        _emo_pluthick_.PolygonPatch(
            c, fc="grey", ec=(0.5, 0.5, 0.5, 0.3), alpha=0.1, zorder=-2
        )
    )

    c = plt.Circle(
        (0, 0), mmax, color="grey", alpha=0.4, fill=False, zorder=-1, linestyle="--"
    )
    ax.add_artist(c)

    if reject_range[0] > rescale[0]:
        c = sg.Point(0, 0).buffer(mmin)
        ax.add_patch(
            _emo_pluthick_.PolygonPatch(c, fc="white", ec=(0.5, 0.5, 0.5, 0), zorder=-1)
        )

        c = plt.Circle(
            (0, 0), mmin, color="grey", alpha=0.4, fill=False, zorder=-1, linestyle="--"
        )
        ax.add_artist(c)

    return ax


def get_random_emotions(intensity_levels=False):
    """
    Gets a dict with emotions, ready to be drawed.

    Required arguments:
    ----------

    *intensity_levels*:
        A boolean: True if emotions petals should be splitted in the correspondent three intensity scores.


    Returns:
    ----------

    A dict <emotion: score>, where score can be either a scalar between 0 and 1, or a 3-item list whose sum is between 0 and 1.

    """

    import random

    emotions = [
        "joy",
        "trust",
        "fear",
        "surprise",
        "sadness",
        "disgust",
        "anger",
        "anticipation",
    ]

    scores = {emotion: random.uniform(0, 1) for emotion in emotions}

    if intensity_levels:
        for emotion in emotions:
            scores_emo = [0, 0, 0]

            scores_emo[0] = random.uniform(0, scores[emotion])
            scores_emo[1] = random.uniform(0, scores[emotion] - scores_emo[0])
            scores_emo[2] = scores[emotion] - sum(scores_emo)

            scores[emotion] = scores_emo

    return scores


def get_random_dyads(dyads_kind="primary"):
    """
    Gets a dict with dyads, ready to be drawed.

    Required arguments:
    ----------

    *dyads_kind*:
        A string: the kind of dyads to get. Accepted values are 'primary', 'secondary', 'tertiary' and 'opposites'


    Returns:
    ----------

    A dict <dyad: score>, where score is a scalar between 0 and 1.

    """

    import random

    if dyads_kind == "primary":
        dyads = [
            "love",
            "submission",
            "alarm",
            "disappointment",
            "remorse",
            "contempt",
            "aggressiveness",
            "optimism",
        ]
    elif dyads_kind == "secondary":
        dyads = [
            "guilt",
            "curiosity",
            "despair",
            "unbelief",
            "envy",
            "cynism",
            "pride",
            "hope",
        ]
    elif dyads_kind == "tertiary":
        dyads = [
            "delight",
            "sentimentality",
            "shame",
            "outrage",
            "pessimism",
            "morbidness",
            "dominance",
            "anxiety",
        ]
    elif dyads_kind == "opposite":
        dyads = ["bittersweetness", "ambivalence", "frozenness", "confusion"]
    else:
        print(
            "Dyads kind must be one of 'primary', 'secondary', 'tertiary' or 'opposite'. Did not recognized '{}': fall back to primary dyads.".format(
                dyads_kind
            )
        )
        dyads = [
            "love",
            "submission",
            "alarm",
            "disappointment",
            "remorse",
            "contempt",
            "aggressiveness",
            "optimism",
        ]

    scores = {dyad: random.uniform(0, 1) for dyad in dyads}

    return scores


def _check_values(scores, rescale, reject_range):
    """
    Check correctness of values inputed by users.

    Required arguments:
    ----------

    *scores*:
        A dictionary with emotions or dyads.
        For each entry, values accepted are a 3-values iterable (for emotions only) or a scalar value between 0 and 1.
        The sum of the 3-values iterable values must not exceed 1, and no value should be negative.
        See emo_params() and dyad_params() for accepted keys.

        Emotions and dyads are mutually exclusive. Different kinds of dyads are mutually exclusive.

    *rescale*:
        A 2-item tuple. If not None, it rescales the petal length over the two values.
        For more see http://www.github.com/alfonsosemeraro/plutchik/documentation.md

    *reject_range*:
        A 2-item tuple. All petal scores that fall within the range must be considered non-interesting, thus drawed in grey.
        Default is None (no range at all).


    Returns:
    ----------

    A 2-items tuple: the new value of the `rescale` argument.

    """
    min_score = np.inf
    max_score = -np.inf

    for key in scores.keys():

        # Check correctedness of values
        if hasattr(scores[key], "__iter__"):
            if (not reject_range) and any([e < 0 for e in scores[key]]):
                raise Exception(
                    "Bad input for `{}`. Emotion/dyads scores should be positive.".format(
                        key
                    )
                )
            tmp = sum(scores[key])

        else:
            #            if (not reject_range) and scores[key] < 0:
            #                raise Exception("Bad input for `{}`. Emotion scores should be positive.".format(key))
            tmp = scores[key]

        # If reject_range, values must be rescaled accordingly
        # Now we take extremes...
        min_score = tmp if tmp < min_score else min_score
        max_score = tmp if tmp > max_score else max_score
        abs_max = max([abs(min_score), abs(max_score)])

    # ...and now we can compute normalization!

    # Case A: users tell a reject_range, but don't decide any normalization scale: we do
    if (not rescale) and (reject_range):
        # max_score = max_score if max_score > reject_range[1] else reject_range[1]
        # min_score = min_score if min_score < reject_range[0] else reject_range[0]
        # emo_diff = max_score - min_score
        # min_score -= emo_diff*.1
        # max_score += emo_diff*.1
        # rescale = (min_score, max_score)
        abs_max = max([reject_range[1], abs_max, abs(reject_range[0])])
        rescale = (-1.5 * abs_max, 1.5 * abs_max)

    # Case B: users tell a reject_range, and they decide a normalization scale: we check correctness
    elif rescale and reject_range:
        if (rescale[0] > reject_range[0]) or (rescale[1] < reject_range[1]):
            raise Exception(
                "Bad input for `rescale` and `reject_range` arguments: rejection range is outside the rescaled area."
            )

        if (rescale[0] > min_score) or (rescale[1] < max_score):
            raise Exception(
                "Bad input for `rescale` argument: at least one petal is outside the rescale area. Minimum values are ({}, {})".format(
                    min_score, max_score
                )
            )

    # Case C: users don't tell a reject_range, and they decide a normalization scale: pass
    elif (not reject_range) and rescale:
        if (rescale[0] > min_score) or (rescale[1] < max_score):
            print(min_score, max_score, rescale)
            raise Exception(
                "Bad input for `rescale` argument: at least one petal is outside the rescale area. Minimum values are ({}, {})".format(
                    min_score, max_score
                )
            )

    # Case D: users don't tell a reject_range nor a normalization: we decide [0,1] unless max_value is higher
    elif (not reject_range) and (not rescale):
        if min_score >= 0 and max_score <= 1:
            rescale = (0, 1)
        else:
            emo_diff = max_score - min_score
            min_score -= emo_diff * 0.1
            max_score += emo_diff * 0.1
            rescale = (min_score, max_score)

    return rescale


def draw_plutchik(
    scores,
    ax=None,
    rescale=None,
    reject_range=None,
    highlight="all",
    show_intensity_levels="none",
    font=None,
    fontweight="light",
    fontsize=15,
    show_coordinates=True,
    show_ticklabels=False,
    ticklabels_angle=0,
    ticklabels_size=11,
    height_width_ratio=1,
    title=None,
    title_size=None,
):
    """
    Draw the emotions or dyads Plutchik flower.
    Full details at https://github.com/alfonsosemeraro/pyplutchik/blob/master/Documentation.md

    Required arguments:
    ----------

    *scores*:
        A dictionary with emotions or dyads.
        For each entry, values accepted are a 3-values iterable (for emotions only) or a scalar value between 0 and 1.
        The sum of the 3-values iterable values must not exceed 1, and no value should be negative.
        See emo_params() and dyad_params() for accepted keys.

        Emotions and dyads are mutually exclusive. Different kinds of dyads are mutually exclusive.

    *ax*:
        Axes to draw the coordinates.

    *rescale*:
        Either None or a 2-item tuple, with minimum and maximum value of the printable area.

    *reject_range*:
        A 2-item tuple. All petal scores that fall within the range must be considered non-interesting, thus drawed in grey.
        Default is None (no range at all).

    *highlight*:
        A string or a list of main emotions to highlight. If a list of emotions is given, other emotions will be shadowed. Default is 'all'.

    *show_intensity_levels*:
        A string or a list of main emotions. It shows all three intensity scores for each emotion in the list, and for the others cumulative scores. Default is 'none'.

    *font*:
        Font of text. Default is sans-serif.

    *fontweight*:
        Font weight of text. Default is light.

    *fontsize*:
        Font size of text. Default is 15.

    *show_coordinates*:
        A boolean, wether to show polar coordinates or not.

    *show_ticklabels*:
        Boolean, wether to show tick labels under Joy petal. Default is False.

    *ticklabels_angle*:
        How much to rotate tick labels from y=0. Value should be given in radians. Default is 0.

    *ticklabels_size*:
        Size of tick labels. Default is 11.

    *height_width_ratio*:
        Ratio between height and width of the petal. Lower the ratio, thicker the petal. Default is 1.

    *title*:
        Title for the plot.

    *title_size*:
        Size of the title. Default is font_size.

    Returns:
    ----------
    *ax*:
        The input Axes modified.

    """

    # Lowering emotions/dyads names
    scores = {key.lower(): val for key, val in scores.items()}

    if any([np.isnan(val) for val in scores.values()]):
        scores = {key: 0 if np.isnan(val) else val for key, val in scores.items()}

    # Checking for correctness of scores
    rescale = _check_values(scores, rescale, reject_range)

    # Check if dyads or emotions, and what kind of dyads
    score_is_emotions = _check_scores_kind(scores)
    if score_is_emotions:
        emotions, dyads = scores, None
    else:
        emotions, dyads = None, scores

    # Create subplot if is not provided as parameter
    if not ax:
        fig, ax = plt.subplots(figsize=(8, 8))

    # Managing fonts
    if not font:
        font = "sans-serif"

    # Drawing the rejection range
    if reject_range:
        _draw_rejection_region(ax, reject_range, rescale)

    # Draw coordinates (if needed) before any petal
    if show_coordinates:
        all_ticks = reject_range == None
        _polar_coordinates(
            ax=ax,
            font=font,
            fontweight=fontweight,
            fontsize=fontsize,
            show_ticklabels=show_ticklabels,
            ticklabels_angle=ticklabels_angle,
            ticklabels_size=ticklabels_size,
            all_ticks=all_ticks,
            rescale=rescale,
        )

    # Draw inner white circle
    _neutral_central_circle(ax)

    # Emotions and dyads are mutually exclusive
    if emotions:

        for emo in emotions:
            # Draw emotion petal
            _emo_pluthick_._draw_emotion_petal(
                ax,
                emotion_score=emotions[emo],
                emotion=emo,
                font=font,
                fontweight=fontweight,
                fontsize=fontsize,
                highlight=highlight,
                show_intensity_levels=show_intensity_levels,
                show_coordinates=show_coordinates,
                height_width_ratio=height_width_ratio,
                reject_range=reject_range,
                rescale=rescale,
            )

    elif dyads:

        for dyad in dyads:

            # Draw dyad bicolor petal
            _dyads_pluthick_._draw_dyad_petal(
                ax,
                dyad_score=dyads[dyad],
                dyad=dyad,
                font=font,
                fontweight=fontweight,
                fontsize=fontsize,
                highlight=highlight,
                show_coordinates=show_coordinates,
                height_width_ratio=height_width_ratio,
                reject_range=reject_range,
                rescale=rescale,
            )

        # Annotation inside the circle
        _, _, _, level = _dyads_pluthick_.dyad_params(
            list(dyads.keys())[0]
        )  # get the first dyad level (they all are the same)
        ll = level if level != 4 else "opp."  # what to annotate
        xy = (
            (-0.03, -0.03) if level != 4 else (-0.13, -0.03)
        )  # exact center of '1' or 'opp' is slightly different
        ax.annotate(
            text=ll,
            xy=xy,
            fontsize=fontsize,
            fontfamily=font,
            fontweight="bold",
            zorder=30,
        )

        # Ghost dotted track that connects colored arcs
        c = plt.Circle(
            (0, 0),
            1.60,
            color="grey",
            alpha=0.3,
            fill=False,
            zorder=-20,
            linestyle="dotted",
        )
        ax.add_artist(c)

    # Adjusting printable area size
    lim = 1.6 if show_coordinates else 1.2
    lim = lim + 0.1 if dyads else lim

    ax.set_xlim((-lim, lim))
    ax.set_ylim((-lim, lim))

    # Default is no axis
    ax.axis("off")

    # Title and title size
    if not title_size:
        title_size = fontsize

    if title:
        ax.set_title(
            title, fontfamily=font, fontsize=title_size, fontweight="bold", pad=20
        )

    return ax


#
# def draw_plutchik_comparison(scores_list,
#             ax = None,
#             rescale = False,
#             reject_range = None,
#             highlight = 'all',
#             show_intensity_levels = 'none',
#             font = None,
#             fontweight = 'light',
#             fontsize = 15,
#             show_coordinates = True,
#             show_ticklabels = False,
#             ticklabels_angle = 0,
#             ticklabels_size = 11,
#             height_width_ratio = 1,
#             title = None,
#             title_size = None):
#    """
#    Draw the emotions or dyads Plutchik flower.
#    Full details at https://github.com/alfonsosemeraro/pyplutchik/blob/master/Documentation.md
#
#    Required arguments:
#    ----------
#
#    *scores*:
#        A list of dictionaries with emotions or dyads.
#        For each entry of each dictionary, values accepted are a 3-values iterable (for emotions only) or a scalar.
#        See https://github.com/alfonsosemeraro/pyplutchik/blob/master/Documentation.md for accepted keys.
#
#        Emotions and dyads are mutually exclusive. Different kinds of dyads are mutually exclusive.
#
#    *ax*:
#        Axes to draw the coordinates.
#
#    *rescale*:
#        Either False or a 2-item tuple, with minimum and maximum value of the printable area.
#
#    *reject_range*:
#        A 2-item tuple. All petal scores that fall within the range must be considered non-interesting, thus drawed in grey.
#        Default is None (no range at all).
#
#    *highlight*:
#        A string or a list of main emotions/dyads to highlight. If a list of emotions/dyads is given, other emotions/dyads will be shadowed. Default is 'all'.
#
#    *show_intensity_levels*:
#        A string or a list of main emotions. It shows all three intensity scores for each emotion in the list, and for the others cumulative scores. Default is 'none'.
#
#    *font*:
#        Font of text. Default is sans-serif.
#
#    *fontweight*:
#        Font weight of text. Default is light.
#
#    *fontsize*:
#        Font size of text. Default is 15.
#
#    *show_coordinates*:
#        A boolean, wether to show polar coordinates or not.
#
#    *show_ticklabels*:
#        Boolean, wether to show tick labels under Joy petal. Default is False.
#
#    *ticklabels_angle*:
#        How much to rotate tick labels from y=0. Value should be given in radians. Default is 0.
#
#    *ticklabels_size*:
#        Size of tick labels. Default is 11.
#
#    *height_width_ratio*:
#        Ratio between height and width of the petal. Lower the ratio, thicker the petal. Default is 1.
#
#    *title*:
#        Title for the plot.
#
#    *title_size*:
#        Size of the title. Default is font_size.
#
#    Returns:
#    ----------
#    *ax*:
#        The input Axes modified.
#
#    """
#
#    # Lowering emotions/dyads names
#    scores_list = [{key.lower(): val for key, val in scores.items()} for scores in scores_list]
#
#    # Checking for correctness of scores
#    rescale_values = [_check_values(scores, rescale, reject_range) for scores in scores_list]
#    rescale = (min([rv[0] for rv in rescale_values]), max([rv[1] for rv in rescale_values]))
#
#    # Check if dyads or emotions, and what kind of dyads
#    scores_are_emotions = _check_scores_list_kind(scores_list)
#    if scores_are_emotions:
#        emotions_list, dyads_list = scores_list, None
#    else:
#        emotions_list, dyads_list = None, scores_list
#
#    # Create subplot if is not provided as parameter
#    if not ax:
#        fig, ax = plt.subplots(figsize = (8, 8))
#
#    # Managing fonts
#    if not font:
#        font = 'sans-serif'
#
#
#    ## WE ARE HERE!!!!
#
#
#    # Drawing the rejection range
#    if reject_range:
#        _draw_rejection_region(ax, reject_range, rescale)
#
#
#    # Draw coordinates (if needed) before any petal
#    if show_coordinates:
#        all_ticks = reject_range == None
#        _polar_coordinates(ax = ax,
#                           font = font, fontweight = fontweight, fontsize = fontsize,
#                           show_ticklabels = show_ticklabels, ticklabels_angle = ticklabels_angle, ticklabels_size = ticklabels_size,
#                           all_ticks = all_ticks, rescale = rescale)
#
#    # Draw inner white circle
#    _neutral_central_circle(ax)
#
#
#    # Emotions and dyads are mutually exclusive
#    if emotions_list:
#
#        for i, emotions in enumerate(emotions_list):
#            for emo in emotions:
#                # Draw emotion petal
#                _emo_pluthick_._draw_emotion_petal(ax, emotion_score = emotions[emo], emotion = emo,
#                            font = font, fontweight = fontweight, fontsize = fontsize,
#                            highlight = highlight, show_intensity_levels = show_intensity_levels,
#                            show_coordinates = show_coordinates, height_width_ratio = height_width_ratio,
#                            reject_range = reject_range, rescale = rescale,
#                            comparison_tot = len(emotions_list), comparison_index = i)
#
#    elif dyads_list:
#
#        for dyads in dyads_list:
#            for dyad in dyads:
#
#                # Draw dyad bicolor petal
#                _dyads_pluthick_._draw_dyad_petal(ax, dyad_score = dyads[dyad], dyad = dyad,
#                            font = font, fontweight = fontweight, fontsize = fontsize,
#                            highlight = highlight,
#                            show_coordinates = show_coordinates, height_width_ratio = height_width_ratio,
#                            reject_range = reject_range, rescale = rescale)
#
#
#        # Annotation inside the circle
#        _, _, _, level = _dyads_pluthick_.dyad_params(list(dyads.keys())[0]) # get the first dyad level (they all are the same)
#        ll = level if level != 4 else 'opp.' # what to annotate
#        xy = (-0.03, -0.03) if level != 4 else (-0.13, -0.03) # exact center of '1' or 'opp' is slightly different
#        ax.annotate(text = ll, xy = xy, fontsize = fontsize, fontfamily = font, fontweight = 'bold', zorder = 30)
#
#        # Ghost dotted track that connects colored arcs
#        c = plt.Circle((0, 0), 1.60, color = 'grey', alpha = .3, fill = False, zorder = -20, linestyle = 'dotted' )
#        ax.add_artist(c)
#
#
#    # Adjusting printable area size
#    lim = 1.6 if show_coordinates else 1.2
#    lim = lim + 0.1 if dyads_list else lim
#
#    ax.set_xlim((-lim, lim))
#    ax.set_ylim((-lim, lim))
#
#
#    # Default is no axis
#    ax.axis('off')
#
#    # Title and title size
#    if not title_size:
#        title_size = fontsize
#
#    if title:
#        ax.set_title(title, fontfamily = font, fontsize = title_size, fontweight = 'bold', pad = 20)
#
#    return ax
#
